TThemeState class

Constructors

TThemeState({required ThemeMode themeMode, required int primaryColorIndex})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
primaryColor MaterialColor
no setter
primaryColorIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeMode ThemeMode
final

Methods

copyWith({ThemeMode? themeMode, int? primaryColorIndex}) TThemeState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited