ThemeNotifier class

Constructors

ThemeNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state TThemeState
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull TThemeState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() TThemeState
Initialize a Notifier.
listenSelf(void listener(TThemeState? previous, TThemeState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuild() → WhenComplete?
Executes Notifier.build.
inherited
selectColor(int index) → void
toggleTheme() → void
toString() String
A string representation of this object.
inherited
updateShouldNotify(TThemeState previous, TThemeState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited