TWidgetTheme class

Annotations

Constructors

TWidgetTheme({required bool isDarkMode, required TVariant type, required MaterialColor color, required Color container, required Color containerVariant, required Color onContainer, required Color onContainerVariant, Color? outline, Color? outlineVariant, Color? shadow})
const

Properties

backgroundState → WidgetStateProperty<Color?>
no setter
borderSideState → WidgetStateProperty<BorderSide?>
no setter
boxBorder → BoxBorder?
no setter
boxShadow → List<BoxShadow>?
no setter
color → MaterialColor
final
container → Color
final
containerVariant → Color
final
foregroundState → WidgetStateProperty<Color?>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDarkMode → bool
final
onContainer → Color
final
onContainerVariant → Color
final
outline → Color?
final
outlineVariant → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → Color?
final
type → TVariant
final

Methods

copyWith({bool? isDarkMode, TVariant? type, MaterialColor? color, Color? container, Color? containerVariant, Color? onContainer, Color? onContainerVariant, Color? outline, Color? outlineVariant, Color? shadow}) → TWidgetTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild({bool? isDarkMode, Color? color, TVariant? type}) → TWidgetTheme
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearCache() → void
fieldTheme(BuildContext context, {TVariant variant = TVariant.tonal}) → TWidgetTheme
filledOutlineTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
filledTextTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
from(bool isDarkMode, Color color, TVariant type) → TWidgetTheme
outlineTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
softOutlineTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
softTextTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
solidTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
surfaceTheme(ColorScheme colors, {TVariant variant = TVariant.tonal}) → TWidgetTheme
textTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme
tonalTheme(Color color, [bool isDarkMode = false]) → TWidgetTheme