ValueType class

Constructors

ValueType(BaseValueType type, {bool isList = false})
ValueType.from(String typeStr)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isList → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BaseValueType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited