onEach method
Performs the given action on each element and returns the iterable itself
Implementation
Iterable<T> onEach(void Function(T element) action) {
for (final element in this) {
action(element);
}
return this;
}
Performs the given action on each element and returns the iterable itself
Iterable<T> onEach(void Function(T element) action) {
for (final element in this) {
action(element);
}
return this;
}