TextStyleX extension

on

Properties

lighter → TextStyle

Available on TextStyle, provided by the TextStyleX extension

Convenience getter to make the text one step lighter (-1).
no setter
thicker → TextStyle

Available on TextStyle, provided by the TextStyleX extension

Convenience getter to make the text one step thicker (+1).
no setter

Methods

adjust({double? sizeMultiplier, int? weightStep, double? fontSize, FontWeight? fontWeight, Color? color, bool clearColor = false, Color? backgroundColor, double? letterSpacing, double? wordSpacing, double? height, Paint? foreground, Paint? background, TextDecoration? decoration, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, String? fontFamily, List<String>? fontFamilyFallback, List<Shadow>? shadows, FontStyle? fontStyle}) → TextStyle

Available on TextStyle, provided by the TextStyleX extension

Returns a new TextStyle with adjusted properties such as sizeMultiplier and weightStep.
scale(double multiplier) → TextStyle

Available on TextStyle, provided by the TextStyleX extension

Scales the fontSize by multiplier if fontSize is not null.
stepWeight([int steps = 1]) → TextStyle

Available on TextStyle, provided by the TextStyleX extension

Steps fontWeight by steps (positive = bolder/thicker, negative = lighter). If fontWeight is null, defaults to FontWeight.normal before stepping.