thicker property
TextStyle
get
thicker
Convenience getter to make the text one step thicker (+1).
Implementation
TextStyle get thicker => stepWeight(1);
Convenience getter to make the text one step thicker (+1).
TextStyle get thicker => stepWeight(1);