TDateTimeInputFormatter class

Inheritance

Constructors

TDateTimeInputFormatter({required TDateTimeFormatType type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TDateTimeFormatType
final

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

format(Object? input, TDateTimeFormatType type) → String
Formats an input value (ISO string, DateTime, formatted string, or raw digits) into the target format.