TCountry class

Constructors

TCountry({required String name, required String code, required String dialCode, required String flag, required String format, required List<String> timezones})
const

Properties

code String
final
dialCode String
final
flag String
final
format String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timezones List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited