TLocationHelper class

Constructors

TLocationHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canFetchLocation() Future<bool>
getCurrentLocation(LocationSettings locationSettings) Future<Position?>
getCurrentLocationUpdates(LocationSettings locationSettings) Future<Stream<Position>?>
getLocationSettings({LocationAccuracy accuracy = LocationAccuracy.high, ActivityType activityType = ActivityType.automotiveNavigation, int distanceFilter = 100, Duration interval = const Duration(seconds: 10), String notificationTitle = "Running in Background", String notificationText = "App will continue to receive your location even when you aren't using it"}) → LocationSettings