TSearchFilter<T> class

Constructors

TSearchFilter({required String itemToString(T)})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemToString → String Function(T)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Iterable<T> items, String query) → List<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited