TFormats class
Constructors
- TFormats()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentCurrencySymbol ↔ String
-
getter/setter pair
- currentDateFormat ↔ String
-
getter/setter pair
- currentDateTimeFormat ↔ String
-
getter/setter pair
- currentTimeFormat ↔ String
-
getter/setter pair
Constants
- dateDescriptive → const String
- e.g. 18 Jun 2026
- dateFull → const String
- e.g. June 18, 2026
- dateShort → const String
- e.g. Jun 18, 2026
- dateSlash → const String
- e.g. 18/06/2026
- dateSlashUS → const String
- e.g. 06/18/2026
- dateStandard → const String
- e.g. 2026-06-18
- dateTimeDB → const String
- e.g. 2026-06-18 22:15:30
- dateTimeDescriptive → const String
- e.g. 18 Jun 2026, 10:15:30 pm
- dateTimeFull → const String
- e.g. Thursday, June 18, 2026, 10:15:30 pm
- dateTimeISO → const String
- e.g. 2026-06-18T22:15:35Z
- dateTimeRangeDefault → const String
- e.g. 18.06.2026 T 22:15
- time12h → const String
- e.g. 10:15 pm
- time12hWithSec → const String
- e.g. 10:15:30 pm
- time24h → const String
- e.g. 22:15
- time24hWithSec → const String
- e.g. 22:15:30