WidthHelper class

Constructors

WidthHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

measureText(BuildContext context, String text, TextStyle style) → double
Measures the width of a string with the given style and context.
resolveWidth(BuildContext ctx, Object? action) → double?