TLayout class

Inheritance
Available extensions

Constructors

TLayout({Key? key, List<TSidebarItem> items = const [], Widget? profile, List<Widget>? actions, required Widget child, String? pageTitle, double mainCardRadius = 12, double? minWidth = 235, double maxWidth = 300, double minifiedWidth = 80, bool? isMinimized, TSidebarMode? sidebarMode, bool showHamburgerMenu = false, bool showThemeToggle = true, bool showFullscreenToggle = true, bool showColorToggle = true, bool showLogout = true, VoidCallback? onLogout, TSidebarTheme? sidebarTheme})
const

Properties

actions → List<Widget>?
final
child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
isMinimized → bool?
final
items → List<TSidebarItem>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
mainCardRadius → double
final
maxWidth → double
final
final
minifiedWidth → double
final
minWidth → double?
final
onLogout → VoidCallback?
final
pageTitle → String?
final
profile → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showColorToggle → bool
final
showFullscreenToggle → bool
final
showHamburgerMenu → bool
final
showLogout → bool
final
showThemeToggle → bool
final
sidebarMode → TSidebarMode?
final
sidebarTheme → TSidebarTheme?
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
center({bool when = true}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() → ConsumerStatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ConsumerState<TLayout>
Creates the mutable state for this widget at a given location in the tree.
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) → Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) → bool
The equality operator.
inherited