TAlertService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
confirmArchive(BuildContext context, VoidCallback onConfirm, {String? name})
→ void
-
Shows a confirmation dialog for archiving an item.
-
confirmDelete(BuildContext context, VoidCallback onConfirm, {String? name})
→ void
-
Shows a confirmation dialog for deleting an item.
-
confirmRestore(BuildContext context, VoidCallback onConfirm, {String? name})
→ void
-
Shows a confirmation dialog for restoring an item.
-
error(BuildContext context, String title, String message)
→ void
-
Shows an error alert.
-
info(BuildContext context, String title, String message)
→ void
-
Shows an informational alert.
-
progress(BuildContext context, String title, String message, {Stream<String>? progressStream})
→ TAlertController
-
Shows a progress alert.
-
show(BuildContext context, {dynamic text, String? title, IconData? icon, Color? color, AlertButton? closeButton, AlertButton? confirmButton, bool progress = false, Stream<String>? progressStream, bool hideCloseButton = false, double? width, double? minWidth = 0, double? minHeight = 0, bool persistent = true})
→ TAlertController
-
Shows a custom alert dialog.
-
success(BuildContext context, String title, String message)
→ void
-
Shows a success alert.
-
warning(BuildContext context, String title, String message)
→ void
-
Shows a warning alert.