TBadgeSize class abstract final

Predefined size configurations for TBadge.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dot → const TSize
Status dot size.
lg → const TSize
Large prominent badge size (minW/minH: 24, font: 12.0, icon: 16, hPad: 6, vPad: 2.5, radius: 12).
md → const TSize
Medium badge size (minW/minH: 20, font: 11.0, icon: 14, hPad: 5, vPad: 2.0, radius: 10).
sm → const TSize
Small standard badge size (minW/minH: 18, font: 10.0, icon: 12, hPad: 4, vPad: 1.5, radius: 9).
xs → const TSize
Extra small badge size (minW/minH: 14, font: 9.5, icon: 10, hPad: 3, vPad: 1.0, radius: 7).
xxs → const TSize
Extra extra small badge size (minW/minH: 12, font: 8.5, icon: 8, hPad: 2, vPad: 1, radius: 6).