TBottomBarTextPosition enum

The position and visibility of the text labels in TBottomBar.

Inheritance
Available extensions

Values

rightActive → const TBottomBarTextPosition

Label on the right of icon, only when active.

bottomAlways → const TBottomBarTextPosition

Label below icon, always shown.

bottomActive → const TBottomBarTextPosition

Label below icon, only when active.

none → const TBottomBarTextPosition

No label shown.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TBottomBarTextPosition>
A constant List of the values in this enum, in order of their declaration.