TBreadcrumbs class

A breadcrumb widget that displays the current route hierarchy.

TBreadcrumbs uses GoRouter location and a list of TSidebarItems to generate a sequence of clickable navigation links.

Basic Usage

TBreadcrumbs(
  items: sidebarItems,
)
Inheritance

Constructors

TBreadcrumbs({Key? key, required List<TSidebarItem> items, TextStyle? style, Color? activeColor, Widget separator = const Opacity(opacity: 0.5, child: Padding(padding: EdgeInsets.symmetric(horizontal: 4), child: Icon(Icons.chevron_right, size: 14))), bool includeHome = true, String homeLabel = 'Home', String homeRoute = '/'})
Creates a breadcrumb widget.
const

Properties

activeColor Color?
The color of the last (active) breadcrumb item.
final
hashCode int
The hash code for this object.
no setterinherited
homeLabel String
The label for the home item.
final
homeRoute String
The route for the home item.
final
includeHome bool
Whether to include a "Home" item at the beginning.
final
items List<TSidebarItem>
The list of sidebar items used to look up labels for routes.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separator Widget
The widget used as a separator between items.
final
style TextStyle?
Custom text style for the breadcrumb links.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited