loadingNotifier property
An optional notifier to dynamically update the loading message.
If provided, the button will listen to this notifier and update its text while in the loading state, ignoring loadingText.
Implementation
final ValueNotifier<String>? loadingNotifier;