initialIndex property

int? initialIndex
final

The initial index of the item to show when cycle is true, or the active item index when cycle is false.

If provided, this enables stateful selection. If an item in items has active set to true, that item's index will take precedence.

Implementation

final int? initialIndex;