TButtonGroupTheme class

Theme configuration for TButtonGroup.

TButtonGroupTheme styles a group of buttons, including:

  • Group type (solid, outline, etc.)
  • Button size and shape
  • Spacing and separators
  • Boxed mode decoration
Annotations

Constructors

TButtonGroupTheme({TButtonGroupType type = TButtonGroupType.solid, TButtonSize? size = TButtonSize.md, TButtonShape shape = TButtonShape.normal, Color? color, double spacing = 0, double borderRadius = 6.0, bool enableBoxedMode = false, EdgeInsetsGeometry? boxedPadding, BoxDecoration? boxedDecoration, double? separatorWidth, Color? separatorColor})
Creates a button group theme.
const
TButtonGroupTheme.fromBaseTheme({required BuildContext context, TButtonGroupType type = TButtonGroupType.solid, TButtonSize? size, Color? color, double spacing = 0, double borderRadius = 6.0, bool enableBoxedMode = false})
Creates a theme from the base context.
factory

Properties

borderRadius → double
final
boxedDecoration → BoxDecoration?
final
boxedPadding → EdgeInsetsGeometry?
final
color → Color?
final
enableBoxedMode → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separatorColor → Color?
final
separatorWidth → double?
final
shape → TButtonShape
final
size → TSize?
final
spacing → double
final
type → TButtonGroupType
final

Methods

buildSeparator() → Widget
Builds a visual separator widget.
copyWith({TButtonGroupType? type, TButtonSize? size, Color? color, double? spacing, double? borderRadius, bool? enableBoxedMode, EdgeInsetsGeometry? boxedPadding, BoxDecoration? boxedDecoration, double? separatorWidth, Color? separatorColor}) → TButtonGroupTheme
Creates a copy of the theme with updated properties.
needsSeparator() → bool
Whether separators should be shown based on the group type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited