TButtonShape class

Defines the shape of a button.

Constructors

TButtonShape({required OutlinedBorder border, bool vertical = false})
const

Properties

border OutlinedBorder
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertical bool
final

Methods

copyWith({OutlinedBorder? border, bool? vertical}) TButtonShape
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom(double radius, {bool vertical = false}) TButtonShape
Custom rounded rectangle with defined radius.

Constants

circle → const TButtonShape
Circular shape.
normal → const TButtonShape
Standard rounded rectangle (radius 6.0).
pill → const TButtonShape
Pill shape (stadium border).
tile → const TButtonShape
Tile shape (icon above text, radius 12.0).