TCheckboxGroupItem<T extends Object?> class

Represents a single option in a TCheckboxGroup.

Constructors

TCheckboxGroupItem({required T value, required String label, Color? color})
Creates a checkbox group item.
const
TCheckboxGroupItem.map(T value, {Color? color})
Creates an item where the label is the string representation of the value.

Properties

color → Color?
Optional custom color for this item.
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
The label text to display.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → T
The value associated with this item.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited