TChipSize class abstract final

Predefined size configurations for TChip.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

lg → const TSize
Large prominent chip size (fontSize: 13.5, icon: 15, radius: 8, hPad: 10, vPad: 4).
md → const TSize
Medium standard chip size (fontSize: 12, icon: 13, radius: 6, hPad: 8, vPad: 3).
sm → const TSize
Small compact chip size (fontSize: 10.5, icon: 11, radius: 4, hPad: 6, vPad: 2).