disableBrowserContextMenu static method
Globally disables the native browser context menu in Flutter Web.
Implementation
static Future<void> disableBrowserContextMenu() async {
if (kIsWeb) {
await BrowserContextMenu.disableContextMenu();
}
}
Globally disables the native browser context menu in Flutter Web.
static Future<void> disableBrowserContextMenu() async {
if (kIsWeb) {
await BrowserContextMenu.disableContextMenu();
}
}