enableBrowserContextMenu static method
Globally re-enables the native browser context menu in Flutter Web.
Implementation
static Future<void> enableBrowserContextMenu() async {
if (kIsWeb) {
await BrowserContextMenu.enableContextMenu();
}
}
Globally re-enables the native browser context menu in Flutter Web.
static Future<void> enableBrowserContextMenu() async {
if (kIsWeb) {
await BrowserContextMenu.enableContextMenu();
}
}