widgets/copy-button/copy_button library

Classes

TCopyable
A wrapper widget that pairs text or a custom widget with an inline TCopyButton.
TCopyButton
A button that copies text to the clipboard with animated state feedback.