createDialogWidth property
Custom width for the dialog when creating or editing items in dialog mode.
Implementation
final double? createDialogWidth;
Custom width for the dialog when creating or editing items in dialog mode.
final double? createDialogWidth;