createSideOverlayWidth property
Custom width for the side overlay when creating or editing items in sideOverlay mode.
Implementation
final double? createSideOverlayWidth;
Custom width for the side overlay when creating or editing items in sideOverlay mode.
final double? createSideOverlayWidth;