storageKey property

String? storageKey
final

Optional unique key to identify and persist table layout settings (dense layout, view mode, card layout). If null, settings are automatically persisted by the current route name.

Implementation

final String? storageKey;