TCrudCustomAction<T> class

Defines a custom action button in the TCrudTable.

Constructors

TCrudCustomAction({required String tooltip, required IconData icon, required Color color, required Future<void> onPressed(T item), Future<bool> canPerform(T item)?, bool showFlat = false})
Creates a custom CRUD action.
const

Properties

canPerform → Future<bool> Function(T item)?
Optional check to enable/disable the action for specific items.
final
color → Color
Color of the action button.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
Icon to display.
final
onPressed → Future<void> Function(T item)
Callback when the action is pressed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showFlat → bool
Whether this action should render flat (inline) when TCrudConfig.flatActions is false.
final
tooltip → String
Tooltip text for the action button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited