autoPromptMappingOnDiff property
Whether to automatically prompt the header mapping dialog when uploaded CSV headers differ.
Implementation
final bool autoPromptMappingOnDiff;
Whether to automatically prompt the header mapping dialog when uploaded CSV headers differ.
final bool autoPromptMappingOnDiff;