TCsvFileFormat enum

Supported data and file formats for TCsvParser and TCsvEditor.

Inheritance
Available extensions

Values

csv → const TCsvFileFormat

Standard comma-separated values (,).

tsv → const TCsvFileFormat

Tab-separated values (\t).

semicolon → const TCsvFileFormat

Semicolon-separated values (;).

pipe → const TCsvFileFormat

Pipe-separated values (|).

json → const TCsvFileFormat

JSON formatted data (.json array or wrapped object).

custom → const TCsvFileFormat

Custom delimiter format.

Properties

delimiter → String?
Associated delimiter character if delimited format.
no setter
extension → String
Default file extension (without leading dot).
no setter
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
Associated icon.
no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
label → String
Human-readable label.
no setter
mimeType → MimeType
Mime type for file saving.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortLabel → String
Short badge label.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TCsvFileFormat>
A constant List of the values in this enum, in order of their declaration.