expandedBuilder property
Builder for expanded row content.
When provided, rows can be expanded to show additional details.
Implementation
final TListExpandedBuilder<T, K>? expandedBuilder;
Builder for expanded row content.
When provided, rows can be expanded to show additional details.
final TListExpandedBuilder<T, K>? expandedBuilder;