rowBuilder property
Custom builder for the row.
If provided, this builder is called for each row and can be used to wrap or replace the default row card.
Implementation
final Widget Function(BuildContext ctx, TListItem<T, K> item, int index, Widget row)? rowBuilder;