widgets/diff-viewer/diff_viewer library

Classes

TDiffLine
A line in a diff comparison.
TDiffViewer
A line-by-line text and code difference viewer for audit logs, version histories, database record comparisons, and config revisions.

Enums

TDiffLineType
The status of a line diff.
TDiffViewMode
The visual presentation mode for TDiffViewer.