TDropdownItem class

Constructors

TDropdownItem({IconData? icon, String? text, List<TDropdownItem>? children, VoidCallback? onTap, bool initiallyExpanded = false, Object? extra, bool hidden = false})
const

Properties

children List<TDropdownItem>?
final
extra Object?
final
hasChildren bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hidden bool
final
icon IconData?
final
initiallyExpanded bool
final
isClickable bool
no setter
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited