TDropdownTheme class

Constructors

TDropdownTheme({required Color defaultColor, required Color hoverColor, required Color activeColor, required Color activeBackgroundColor, required Color borderColor, Duration animationDuration = const Duration(milliseconds: 250), Duration showDelay = const Duration(milliseconds: 100), Duration hideDelay = const Duration(milliseconds: 250), TPopupAlignment alignment = TPopupAlignment.bottomLeft, double offset = 8.0, TPopupAlignment secondaryAlignment = TPopupAlignment.rightTop, double secondaryOffset = 8.0, BoxConstraints boxConstraints = const BoxConstraints(minWidth: 175), double iconSize = 20.0, double arrowIconSize = 11.0, double gap = 10.0, double overlayElevation = 12.0, BorderRadius overlayBorderRadius = const BorderRadius.all(Radius.circular(8.0)), EdgeInsets overlayPadding = const EdgeInsets.symmetric(vertical: 8), EdgeInsets itemPadding = const EdgeInsets.symmetric(horizontal: 16, vertical: 12), BorderRadius itemBorderRadius = const BorderRadius.all(Radius.circular(6.0)), double fontSize = 14.0, FontWeight fontWeight = FontWeight.w300})
const
TDropdownTheme.defaultTheme(ColorScheme? colors)
factory

Properties

activeBackgroundColor Color
final
activeColor Color
final
alignment TPopupAlignment
final
animationDuration Duration
final
arrowIconSize double
final
borderColor Color
final
boxConstraints BoxConstraints
final
defaultColor Color
final
fontSize double
final
fontWeight FontWeight
final
gap double
final
hashCode int
The hash code for this object.
no setterinherited
hideDelay Duration
final
hoverColor Color
final
iconSize double
final
itemBorderRadius BorderRadius
final
itemPadding EdgeInsets
final
offset double
final
overlayBorderRadius BorderRadius
final
overlayElevation double
final
overlayPadding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryAlignment TPopupAlignment
final
secondaryOffset double
final
showDelay Duration
final

Methods

getItemColor({required bool isActive, required bool containsActive, required bool isHovered}) Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited