TDropdownItem class

Inheritance

Constructors

TDropdownItem({IconData? icon, String? text, List<TDropdownItem>? children, VoidCallback? onTap, bool initiallyExpanded = false, Object? extra, bool hidden = false, Color? color})
const

Properties

children List<TDropdownItem>?
final
color Color?
final
extra Object?
final
hashCode int
The hash code for this object.
no setterinherited
hasVisibleChildren bool
no setterinherited
hidden bool
final
icon IconData?
final
initiallyExpanded bool
final
isClickable bool
no setteroverride
isHidden bool
no setterinherited
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final
visibleChildren List<TDropdownItem>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tap(BuildContext context) → void
Invoked when the item itself (not a child with a submenu) is activated.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited