TDropdownOverlayController class

Manages a stack of overlays, providing centralized control for showing, hiding, and nesting overlays.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hideAllOverlays() → void
registerOverlay(OverlayPortalController controller) → void
scheduleHide({Duration delay = const Duration(milliseconds: 250)}) → void
setMouseInArea(bool inArea) → void