TEmptyState.noData constructor

const TEmptyState.noData({
  1. Key? key,
  2. dynamic icon = Icons.inbox_outlined,
  3. Widget? image,
  4. String? title = 'No data available',
  5. Widget? titleWidget,
  6. String? description = 'There are no records to display at this time.',
  7. Widget? descriptionWidget,
  8. Widget? action,
  9. Widget? secondaryAction,
  10. bool compact = false,
  11. EdgeInsetsGeometry padding = const EdgeInsets.all(32.0),
  12. Color? iconColor,
  13. Color? iconBackgroundColor,
  14. double? iconSize,
})

Creates a standard "No Data" placeholder.

Implementation

const TEmptyState.noData({
  super.key,
  this.icon = Icons.inbox_outlined,
  this.image,
  this.title = 'No data available',
  this.titleWidget,
  this.description = 'There are no records to display at this time.',
  this.descriptionWidget,
  this.action,
  this.secondaryAction,
  this.compact = false,
  this.padding = const EdgeInsets.all(32.0),
  this.iconColor,
  this.iconBackgroundColor,
  this.iconSize,
});