TEmptyState.notFound constructor

const TEmptyState.notFound({
  1. Key? key,
  2. dynamic icon = Icons.find_in_page_outlined,
  3. Widget? image,
  4. String? title = 'Item Not Found',
  5. Widget? titleWidget,
  6. String? description = 'The item or resource you requested could not be located.',
  7. Widget? descriptionWidget,
  8. Widget? action,
  9. Widget? secondaryAction,
  10. bool compact = false,
  11. EdgeInsetsGeometry padding = const EdgeInsets.all(32.0),
  12. Color? iconColor,
  13. Color? iconBackgroundColor,
  14. double? iconSize,
})

Creates a 404 or missing resource empty state.

Implementation

const TEmptyState.notFound({
  super.key,
  this.icon = Icons.find_in_page_outlined,
  this.image,
  this.title = 'Item Not Found',
  this.titleWidget,
  this.description = 'The item or resource you requested could not be located.',
  this.descriptionWidget,
  this.action,
  this.secondaryAction,
  this.compact = false,
  this.padding = const EdgeInsets.all(32.0),
  this.iconColor,
  this.iconBackgroundColor,
  this.iconSize,
});