isGalleryMode property
Whether to display selected files in gallery mode (100x100 TImage thumbnails with hover overlay).
Implementation
final bool isGalleryMode;
Whether to display selected files in gallery mode (100x100 TImage thumbnails with hover overlay).
final bool isGalleryMode;