widgets/form/form_builder library

Classes

TFieldProp<T>
A reactive property for form fields with subscription support.
TFormBase
Base class for creating structured forms.
TFormBuilder
A responsive form builder with grid and tab layouts.
TFormField<T>
A form field wrapper with factory methods for all input types.
TFormTab
A tab configuration for sub forms within TFormBuilder and TFormField.tabs.
TFormTypePersistence
Helper service for persisting and retrieving user form type layout preference.
TFormTypeScope
Inherited scope providing the active TFormType to descendant form widgets.
TFormTypeToggleSwitch
Toggle switch button for switching form types (accordion, horizontal tabs, vertical tabs).

Enums

TFormType
Form layout presentation types for forms with sub-forms.

Extensions

TFormTypeContextExt on BuildContext
Extension for convenient access to TFormType on BuildContext.