sidebarFields property

List<TFormField>? get sidebarFields

Optional list of fields rendered in the sidebar panel.

When non-null, the form layout splits into a main area and a sidebar whose column span is controlled by sidebarSize. On sm/md breakpoints (where sidebarSize span is 0) the sidebar fields are appended below the main fields in a single column.

Implementation

List<TFormField>? get sidebarFields => null;