storageKey property
String?
get
storageKey
Optional custom storage identifier for persisting form layout preference.
Implementation
String? get storageKey => null;
Optional custom storage identifier for persisting form layout preference.
String? get storageKey => null;