widgets/grid/grid library

Classes

TGridCol
A responsive grid column to be used within a TGridRow.
TGridRow
A responsive grid row that uses a 12-column system.
TGridSize
Defines the column span of a component at different breakpoints.

Enums

TBreakpoint
Screen width breakpoints for responsive layouts.

Constants

kDesktopBreakpoint → const double
Minimum width (inclusive) for desktop/large screens.
kMobileBreakpoint → const double
Minimum width (inclusive) for tablet/medium screens.