TIcon class

An interactive icon with hover, active states, and rotation.

TIcon provides an enhanced icon widget with:

  • Hover and active states
  • Color transitions
  • Rotation animations
  • Tap handling
  • Custom sizing and padding

Basic Usage

TIcon(
  icon: Icons.favorite,
  onTap: () => print('Tapped'),
)

With Active State

TIcon(
  icon: Icons.favorite_border,
  activeIcon: Icons.favorite,
  active: isFavorite,
  color: Colors.grey,
  activeColor: Colors.red,
  onTap: () => setState(() => isFavorite = !isFavorite),
)

With Rotation

TIcon(
  icon: Icons.refresh,
  turns: (0, 1),  // Rotate 360° when active
  active: isRefreshing,
  onTap: () => refresh(),
)

See also:

Inheritance
Available extensions

Constructors

TIcon({Key? key, required dynamic icon, VoidCallback? onTap, double size = 16, bool active = false, EdgeInsets padding = const EdgeInsets.all(6), (double, double)? turns, int animationMilliseconds = 200, Color? color, dynamic activeIcon, Color? activeColor, Color? hoverColor, BoxShape shape = BoxShape.rectangle, Color? background, BorderRadius? borderRadius = const BorderRadius.all(Radius.circular(10)), TThemeType? themeType, List<BoxShadow>? shadow})
Creates an icon.
const
TIcon.close({VoidCallback? onTap, double size = 20, EdgeInsets padding = const EdgeInsets.all(8)})
Creates a close icon with default styling.
factory
TIcon.raw(dynamic icon, {Key? key, double size = 16, Color? color, Color? activeColor, Color? hoverColor, dynamic activeIcon, bool active = false, (double, double)? turns, int animationMilliseconds = 200, VoidCallback? onTap, TThemeType? themeType})
Creates a raw icon with no padding, background, shape, border radius, or container wrapping.
factory

Properties

active → bool
Whether the icon is in active state.
final
activeColor → Color?
The color when active.
final
activeIcon → dynamic
Alternative icon to show when active.
final
animationMilliseconds → int
Duration of rotation animation in milliseconds.
final
background → Color?
final
borderRadius → BorderRadius?
final
color → Color?
The default color of the icon.
final
hashCode → int
The hash code for this object.
no setterinherited
hoverColor → Color?
The color on hover.
final
icon → dynamic
The icon to display. Supports IconData, List<List<dynamic>> (HugeIcon), or Widget.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → VoidCallback?
Callback fired when the icon is tapped.
final
padding → EdgeInsets
Padding around the icon.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → List<BoxShadow>?
final
shape → BoxShape
final
size → double
The size of the icon.
final
themeType → TThemeType?
final
turns → (double, double)?
Rotation turns (initial, active) for animation.
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center({bool when = true}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) → Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) → bool
The equality operator.
inherited