forceCache property
When true, the image is downloaded once and stored persistently in
IndexedDB (web) or the app documents directory (Android/iOS/desktop)
via TImageStorage.
Implementation
final bool forceCache;
When true, the image is downloaded once and stored persistently in
IndexedDB (web) or the app documents directory (Android/iOS/desktop)
via TImageStorage.
final bool forceCache;