height property

double? height
final

Explicit height of the image. If width is null:

  • If aspectRatio is provided, width is calculated as height * aspectRatio.
  • If aspectRatio is null, width adapts automatically to the content.

Implementation

final double? height;