width property

double? width
final

Explicit width of the image. If height is null:

  • If aspectRatio is provided, height is calculated as width / aspectRatio.
  • If aspectRatio is null, height adapts automatically to the content.

Implementation

final double? width;