block property
Whether the container should expand to fill available horizontal width.
Defaults to true (matches input fields). When false, wraps the content.
Implementation
final bool block;
Whether the container should expand to fill available horizontal width.
Defaults to true (matches input fields). When false, wraps the content.
final bool block;