showCopyButton property
Whether to show copy buttons for the entire JSON payload and individual nodes. Defaults to true.
Implementation
final bool showCopyButton;
Whether to show copy buttons for the entire JSON payload and individual nodes. Defaults to true.
final bool showCopyButton;