showItemCount property
Whether to show item count indicators for objects and arrays (e.g. { 4 }, [ 12 ]).
Implementation
final bool showItemCount;
Whether to show item count indicators for objects and arrays (e.g. { 4 }, [ 12 ]).
final bool showItemCount;