additionalNaturalWidth property
Extra width added to the calculated natural width of each child.
Implementation
final double additionalNaturalWidth;
Extra width added to the calculated natural width of each child.
final double additionalNaturalWidth;