columnar property

bool columnar
final

Whether to arrange items in a columnar grid. When true (or when columns is set), items are arranged in uniform columns with aligned keys. When false (default), items flow dynamically into rows based on natural widths.

Implementation

final bool columnar;