columns property
Fixed number of columns for grid layout. When specified, items are distributed into a columnar grid of this width.
Implementation
final int? columns;
Fixed number of columns for grid layout. When specified, items are distributed into a columnar grid of this width.
final int? columns;