rawGap property
double?
get
rawGap
The explicitly configured gap between key and value, or null if using mode-based default.
Implementation
double? get rawGap => _gap;
The explicitly configured gap between key and value, or null if using mode-based default.
double? get rawGap => _gap;