rawHSpacing property
double?
get
rawHSpacing
The explicitly configured horizontal spacing, or null if using mode-based default.
Implementation
double? get rawHSpacing => _hSpacing;
The explicitly configured horizontal spacing, or null if using mode-based default.
double? get rawHSpacing => _hSpacing;