rawVSpacing property
double?
get
rawVSpacing
The explicitly configured vertical spacing, or null if using mode-based default.
Implementation
double? get rawVSpacing => _vSpacing;
The explicitly configured vertical spacing, or null if using mode-based default.
double? get rawVSpacing => _vSpacing;