selectable property
Whether text values should be selectable with text selection gestures. Defaults to false so parent card/container tap events work smoothly.
Implementation
final bool selectable;
Whether text values should be selectable with text selection gestures. Defaults to false so parent card/container tap events work smoothly.
final bool selectable;