TListControllerActions<T, K> extension

Extension providing error handling, item editing/creation, and additional state actions for TListController.

on

Methods

beginCreateItem({bool clearEditingItem = true}) → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Puts the list into a state ready to create a new item.
beginEditItem(T item) → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Puts the list into a state ready to edit an item.
beginEditItemKey(K key) → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Puts the list into a state ready to edit an item key.
cancelCreateItem() → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Cancels the create item state.
cancelEditItem() → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Cancels the edit item state.
cancelPendingOperations() → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Cancels all pending debouncer timers and network requests.
clearAdditionalState() → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Clears the additional state and notifies listeners.
clearError() → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Clears any error state.
handleError(TListError error) → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Sets an error state on the list.
setAdditionalState(String key, dynamic value) → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Sets a value in the additional state and notifies listeners if it changed.
updateError(Object e, StackTrace st) → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Helper to wrap exception and stacktrace into a TListError.
updateLoading() → void

Available on TListController<T, K>, provided by the TListControllerActions extension

Puts the list into a loading state.