updateError method
Helper to wrap exception and stacktrace into a TListError.
Implementation
void updateError(Object e, StackTrace st) {
handleError(TListError(message: e.toString(), error: e, stackTrace: st));
}
Helper to wrap exception and stacktrace into a TListError.
void updateError(Object e, StackTrace st) {
handleError(TListError(message: e.toString(), error: e, stackTrace: st));
}