addItem method
Adds a single item.
Throws if an item with the same key already exists.
Implementation
void addItem(T item, {K? parentKey, bool prepend = true}) {
addItems([item], parentKey: parentKey, prepend: prepend);
}
Adds a single item.
Throws if an item with the same key already exists.
void addItem(T item, {K? parentKey, bool prepend = true}) {
addItems([item], parentKey: parentKey, prepend: prepend);
}