TLoadOptions<T> class

Options for loading data in the list.

Constructors

TLoadOptions({required int page, required int itemsPerPage, String? search, String? cursor, Map<String, dynamic>? advancedSearch})
Creates load options.
const

Properties

advancedSearch → Map<String, dynamic>?
Advanced search filters as a generic map for endpoint-specific parameters.
final
cursor → String?
Cursor for cursor-based pagination (nullable).
final
hashCode → int
The hash code for this object.
no setteroverride
itemsPerPage → int
Number of items per page.
final
limit → int
Limit for pagination.
no setter
offset → int
Calculated offset for pagination.
no setter
page → int
The page number to load (1-based).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Search query string.
final

Methods

copyWith({int? page, int? itemsPerPage, String? search, String? cursor, Map<String, dynamic>? advancedSearch}) → TLoadOptions<T>
Creates a copy with updated properties.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override