emptyDescription property
Optional description text in the default empty state. Defaults to 'Select an item from the list to view its details'.
Implementation
final String? emptyDescription;
Optional description text in the default empty state. Defaults to 'Select an item from the list to view its details'.
final String? emptyDescription;