TListState<T, K> class

Constructors

TListState({required LinkedHashSet<K> selectedKeys, required LinkedHashSet<K> expandedKeys, required List<TListItem<T, K>> displayItems, required int page, required int itemsPerPage, required int totalItems, required bool loading, required bool fetching, required bool hasMoreItems, required String search, TListError? error, K? expandedDetailKey, K? editingItemKey, bool isCreatingItem = false, String? currentCursor, String? nextCursor, List<String> cursorHistory = const [], Map<String, dynamic>? advancedSearch, Map<String, dynamic> additional = const {}})
const

Properties

activeKey → K?
no setter
additional → Map<String, dynamic>
final
advancedSearch → Map<String, dynamic>?
final
currentCursor → String?
final
cursorHistory → List<String>
final
displayItems → List<TListItem<T, K>>
final
editingItemKey → K?
final
error → TListError?
final
expandedDetailKey → K?
final
expandedKeys → LinkedHashSet<K>
final
fetching → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasMoreItems → bool
final
isCreatingItem → bool
final
isEditingItem → bool
no setter
itemsPerPage → int
final
loading → bool
final
nextCursor → String?
final
page → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
selectedKeys → LinkedHashSet<K>
final
totalItems → int
final

Methods

copyWith({LinkedHashSet<K>? selectedKeys, LinkedHashSet<K>? expandedKeys, List<TListItem<T, K>>? displayItems, int? page, int? itemsPerPage, int? totalItems, bool? loading, bool? fetching, bool? hasMoreItems, String? search, TListError? error, K? expandedDetailKey, K? editingItemKey, bool? isCreatingItem, String? currentCursor, String? nextCursor, List<String>? cursorHistory, Map<String, dynamic>? advancedSearch, Map<String, dynamic>? additional}) → TListState<T, K>
Creates a copy of this state with the given fields updated.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited