TGoogleClient class

Google Client to interact with the new Google Places API v1 endpoints.

Constructors

TGoogleClient({Dio? dio, String? googleMapApiKey})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

autocomplete(String input, {TGooglePlacesConfig? config, List<String> fieldMasks = defaultAutocompleteFieldMasks}) Future<TGoogleAutocompleteResponse>
Get auto-complete suggestions from Google Places API.
fetchPlaceDetails(String placeId, {List<String> fields = defaultPlaceDetailsFields, String? sessionToken}) Future<TGooglePlaceDetailsResponse>
Fetch place details by ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited