TGooglePlacePrediction class

Prediction model for places.

Constructors

TGooglePlacePrediction({required String place, required String placeId, TGooglePredictionText? text, TGoogleStructuredFormat? structuredFormat, List<String>? types})
const
TGooglePlacePrediction.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
place String
final
placeId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredFormat TGoogleStructuredFormat?
final
text TGooglePredictionText?
final
types List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited