TGooglePlacesConfig class

Request configuration for Google Places Autocomplete API.

Constructors

TGooglePlacesConfig({String? languageCode, String? regionCode, LatLng? origin, TGoogleLocationBias? locationBias, TGoogleLocationRestriction? locationRestriction, List<String>? includedPrimaryTypes, bool? includeQueryPredictions, int? inputOffset, bool? includeFutureOpeningBusinesses, bool? includePureServiceAreaBusinesses, String? sessionToken})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includedPrimaryTypes List<String>?
final
includeFutureOpeningBusinesses bool?
final
includePureServiceAreaBusinesses bool?
final
includeQueryPredictions bool?
final
inputOffset int?
final
languageCode String?
final
locationBias TGoogleLocationBias?
final
locationRestriction TGoogleLocationRestriction?
final
origin LatLng?
final
regionCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionToken String?
final

Methods

copyWith({String? languageCode, String? regionCode, LatLng? origin, TGoogleLocationBias? locationBias, TGoogleLocationRestriction? locationRestriction, List<String>? includedPrimaryTypes, bool? includeQueryPredictions, int? inputOffset, bool? includeFutureOpeningBusinesses, bool? includePureServiceAreaBusinesses, String? sessionToken}) TGooglePlacesConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(String input) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited