TGoogleStructuredFormat class

Structured format model for Autocomplete predictions.

Constructors

TGoogleStructuredFormat({TGooglePredictionText? mainText, TGooglePredictionText? secondaryText})
const
TGoogleStructuredFormat.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mainText TGooglePredictionText?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryText TGooglePredictionText?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited