TMapPinning class

Inheritance
Mixed-in types
Available extensions

Constructors

TMapPinning({Key? key, String? placeholder, required String label, TextEditingController? addressController, LatLng? initialCoordinates, ValueChanged<LatLng>? onCoordinatesChanged, ValueChanged<String>? onAddressChanged, bool disabled = false, String? tag, String? helperText, bool isRequired = false, String? info, bool clearable = false, TInputFieldTheme? theme, VoidCallback? onTap, VoidCallback? onShow, VoidCallback? onHide, String? googleMapApiKey, TLoadListener<TPlaceResult>? onLoad})
const

Properties

addressController TextEditingController?
final
alignment TPopupAlignment
Preferred alignment of the popup.
no setteroverride
clearable bool
Whether the field shows a clear button when it has a value.
final
disabled bool
Whether the popup is disabled.
final
googleMapApiKey String?
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
The helper text.
final
info String?
The info text (optional).
final
initialCoordinates LatLng?
final
isRequired bool
Whether the field is required.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
The label text.
final
offset double
Offset from the target widget.
no setterinherited
onAddressChanged ValueChanged<String>?
final
onCoordinatesChanged ValueChanged<LatLng>?
final
onHide VoidCallback?
Callback when popup hides.
final
onLoad TLoadListener<TPlaceResult>?
final
onShow VoidCallback?
Callback when popup shows.
final
onTap VoidCallback?
Callback for tap events.
final
placeholder String?
final
popupMode TPopupMode?
Preferred display mode of the popup.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool
Whether to show a close button in the popup.
no setterinherited
tag String?
The tag text (optional).
final
theme TInputFieldTheme?
Custom theme.
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
center({bool when = true}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TMapPinning>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) bool
The equality operator.
inherited