itemInfoGridInline property
Whether to display key and value inline in grid layout (Key: Value) for itemInfo. Defaults to true.
Implementation
final bool itemInfoGridInline;
Whether to display key and value inline in grid layout (Key: Value) for itemInfo. Defaults to true.
final bool itemInfoGridInline;