TPdfWidgetHelper class

Helper for converting Flutter widgets to PDF widgets.

Constructors

TPdfWidgetHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convert(Widget widget, ColorScheme colors, {Map<String, Uint8List>? imageCache}) → Widget
Converts supported Flutter widgets (like TImage, TChip) to their PDF equivalents.
preCacheImages<T, K>(BuildContext context, List<TTableHeader<T, K>> headers, List<T> items) Future<Map<String, Uint8List>>
Pre-fetches images from network or assets for a list of items and headers.