TPdfGridTableHelper class

Helper for creating grid-based layouts in PDF documents.

TPdfGridTableHelper mimics the behavior of TKeyValueSection's grid layout, allowing key-value pairs to be arranged in a responsive-like grid within a PDF.

Constructors

TPdfGridTableHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

adaptive<T, K>(BuildContext context, List<TTableHeader<T, K>> headers, List<T> items, {TPdfTableDecoration decoration = const TPdfTableDecoration(), double availableWidth = 515, TKeyValueTheme? theme, Map<String, Uint8List>? imageCache}) Future<Widget>
Creates an adaptive layout: uses a standard table if it fits, otherwise uses a grid.
from(BuildContext context, List<TKeyValue> values, {TPdfTableDecoration decoration = const TPdfTableDecoration(), double availableWidth = 515, TKeyValueTheme? theme, Map<String, Uint8List>? imageCache, double gridSpacing = 0}) → Widget
Creates a grid layout from a list of TKeyValue items.
fromHeaders<T, K>(BuildContext context, List<TTableHeader<T, K>> headers, T item, {TPdfTableDecoration decoration = const TPdfTableDecoration(), double availableWidth = 515, TKeyValueTheme? theme, Map<String, Uint8List>? imageCache}) → Widget
Creates a grid layout from headers and a single item.