widgets/popover/popover library

Classes

TPopconfirm
A specialized confirmation popover anchored directly to a trigger action.
TPopover
A floating, anchored popup card attached to a target child trigger.
TPopoverController
Controller to programmatically show, hide, or toggle a TPopover.