valueText property

String? valueText
final

Optional custom value text to display inside the circle (e.g. '50 / 1000').

When showPercentage is true, this is displayed below the percentage.

Implementation

final String? valueText;