indeterminate property
Whether the progress is in an unknown state.
When true, the bar displays a continuous flowing animation.
Implementation
final bool indeterminate;
Whether the progress is in an unknown state.
When true, the bar displays a continuous flowing animation.
final bool indeterminate;