inline property
Whether to display the progress bar inline with its label and percentage.
Convenience alias for setting valuePosition to TProgressValuePosition.afterProgress.
Implementation
final bool? inline;
Whether to display the progress bar inline with its label and percentage.
Convenience alias for setting valuePosition to TProgressValuePosition.afterProgress.
final bool? inline;