valuePosition property
The position of the percentage and value text relative to the progress bar.
Defaults to TProgressValuePosition.topRight.
Implementation
final TProgressValuePosition valuePosition;
The position of the percentage and value text relative to the progress bar.
Defaults to TProgressValuePosition.topRight.
final TProgressValuePosition valuePosition;