TProgressValuePosition enum

Position of the percentage or value text relative to the linear progress bar.

Inheritance
Available extensions

Values

topRight → const TProgressValuePosition

Top right corner above the progress bar, opposite the label (default).

topLeft → const TProgressValuePosition

Top left corner above the progress bar, next to the label.

afterProgress → const TProgressValuePosition

Inline after the progress bar horizontally on the same line.

beforeProgress → const TProgressValuePosition

Inline before the progress bar horizontally on the same line.

bottomRight → const TProgressValuePosition

Bottom right below the progress bar.

bottomLeft → const TProgressValuePosition

Bottom left below the progress bar.

inside → const TProgressValuePosition

Centered inside the progress bar (ideal for larger bar heights).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TProgressValuePosition>
A constant List of the values in this enum, in order of their declaration.