visibleItemsCount property

int? visibleItemsCount
final

The number of items to show as visible in the dropdown before scrolling.

For local items (no onLoad), this controls the dropdown height: all items are always rendered but only visibleItemsCount rows are visible before the user needs to scroll. Defaults to 6.

For server-side loading (onLoad), this also controls the dropdown height, while itemsPerPage controls how many items are fetched per request.

Implementation

final int? visibleItemsCount;