TSheetService class

Constructors

TSheetService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showBottomSheet<T>(BuildContext context, TModalWidgetBuilder<T> builder, {TModalWidgetBuilder? header, TModalWidgetBuilder? footer, bool persistent = false, double? height, String? title, bool? showCloseButton, bool showHandle = true, TSheetAnimationType animationType = TSheetAnimationType.sliding}) Future<T?>
showSideSheet<T>(BuildContext context, TModalWidgetBuilder<T> builder, {TModalWidgetBuilder? header, TModalWidgetBuilder? footer, bool persistent = false, double width = 400, String? title, bool? showCloseButton, TSheetAnimationType animationType = TSheetAnimationType.sliding, bool fromLeft = false}) Future<T?>