comparisonLabel property
Optional comparison label text placed after the percentage (e.g. "vs last 30 days").
Implementation
final String? comparisonLabel;
Optional comparison label text placed after the percentage (e.g. "vs last 30 days").
final String? comparisonLabel;