onResized property
Callback fired whenever the split ratio changes due to user dragging or controller updates.
Implementation
final ValueChanged<double>? onResized;
Callback fired whenever the split ratio changes due to user dragging or controller updates.
final ValueChanged<double>? onResized;