TTableRowCard<T, K> class

A standard table row rendered as a card.

TTableRowCard renders a single row in a TTable using a Table layout. It integrates with:

Inheritance
Available extensions

Constructors

TTableRowCard({Key? key, required int index, required TListItem<T, K> item, required List<TTableHeader<T, K>> headers, Map<int, TableColumnWidth>? columnWidths, TTableRowCardTheme? theme, double? width, bool expandable = false, bool isExpanded = false, bool isDetailExpanded = false, VoidCallback? onExpansionChanged, Widget? expandedContent, TTableExpansionMode expansionMode = TTableExpansionMode.bottom, bool expandSide = false, dynamic expandIcon, dynamic collapseIcon, bool selectable = false, bool isSelected = false, VoidCallback? onSelectionChanged, VoidCallback? onTap, Color? backgroundColor})
Creates a table row card.
const

Properties

backgroundColor → Color?
Custom background color for the row.
final
collapseIcon → dynamic
Custom icon for expanded state.
final
columnWidths → Map<int, TableColumnWidth>?
Column width configuration for the underlying Table.
final
expandable → bool
Whether the row is expandable.
final
expandedContent → Widget?
Content to show when expanded.
final
expandIcon → dynamic
Custom icon for collapsed state.
final
expandSide → bool
Whether expansion happens on the side.
final
expansionMode → TTableExpansionMode
The expansion mode for details (bottom, side, dialog, page).
final
hashCode → int
The hash code for this object.
no setterinherited
headers → List<TTableHeader<T, K>>
The table headers definitions.
final
index → int
The index of the item.
final
isDetailExpanded → bool
final
isExpanded → bool
Whether the row is currently expanded.
final
isSelected → bool
Whether the row is selected.
final
item → TListItem<T, K>
The list item data.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onExpansionChanged → VoidCallback?
Callback when expansion toggles.
final
onSelectionChanged → VoidCallback?
Callback when selection toggles.
final
onTap → VoidCallback?
Callback when row card tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectable → bool
Whether the row is selectable.
final
theme → TTableRowCardTheme?
Theme for the row card.
final
width → double?
Optional fixed width.
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center({bool when = true}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) → Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) → bool
The equality operator.
inherited