TTableRowHeaderTheme class

Theme configuration for TTableRowHeader.

TTableRowHeaderTheme styles the header row of a table, including:

  • Padding
  • Decoration (background, border)
  • Text style for column titles

Constructors

TTableRowHeaderTheme({Decoration? decoration, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16, vertical: 12), required TextStyle textStyle})
Creates a table row header theme.
const
TTableRowHeaderTheme.defaultTheme(ColorScheme colors)
factory

Properties

decoration Decoration?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited