TRowExpandedBuilder class

Constructors

TRowExpandedBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

keyValue(BuildContext ctx, List<TKeyValue> values) Widget
tabs(BuildContext ctx, {required List<TTab<String>> tabs, String? initialValue, TTabController<String>? controller, Widget? header, String editTabLabel = 'Edit', String editTabValue = '__edit__', Widget editTabBuilder(BuildContext)?}) Widget