activeCellNotifier property
The active cell notifier tracking which cell is in edit mode.
Implementation
final ValueNotifier<String?> activeCellNotifier;
The active cell notifier tracking which cell is in edit mode.
final ValueNotifier<String?> activeCellNotifier;