isCardView property
Whether the table is currently rendered as cards (mobile/card view) rather than a row-based table.
Implementation
final bool isCardView;
Whether the table is currently rendered as cards (mobile/card view) rather than a row-based table.
final bool isCardView;