minSideExpandWidth property
Minimum width required to show the side list alongside the detail panel in TTableExpansionMode.side.
If available width is less than this threshold (defaults to 700.0), the side list is hidden.
Implementation
final double? minSideExpandWidth;