Validation rules to apply to the field's value.
Each rule is a function that returns an error message string if validation fails, or null if validation passes.
@override final List<String? Function(T?)>? rules;