TTextFieldMixin mixin

Mixin for text field configuration properties.

Superclass constraints
Mixin applications

Properties

autoFocus bool
Whether the field should autofocus.
no setter
clearable bool
Whether the field shows a clear button when it has a value.
no setterinherited
disabled bool
Whether the field is disabled.
no setterinherited
focusNode FocusNode?
Custom focus node.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
helperText String?
The helper text.
no setterinherited
isRequired bool
Whether the field is required.
no setterinherited
label String?
The label text.
no setterinherited
onTap VoidCallback?
Callback for tap events.
no setterinherited
placeholder String?
Placeholder text.
no setter
readOnly bool
Whether the field is read-only.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
The tag text (optional).
no setterinherited
textController TextEditingController?
Custom text controller.
no setter
theme TTextFieldTheme?
Custom theme.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited