TTextFieldStateMixin<W extends StatefulWidget> mixin

State mixin for building text field widgets.

Superclass constraints
Mixin applications

Properties

colors ColorScheme
Access to current color scheme.
no setterinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
focusMixin TFocusStateMixin<StatefulWidget>?
no setterinherited
focusNode FocusNode
The active focus node.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isFocused bool
Whether the widget is currently focused.
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
states Set<WidgetState>
Current interactive states of the widget (focused, error, disabled).
no setterinherited
textController TextEditingController
The active text controller.
no setter
validationMixin TInputValidationStateMixin<dynamic, StatefulWidget>?
no setterinherited
widget → W
The current configuration.
no setterinherited
wTheme TTextFieldTheme
Access to current widget theme.
no setteroverride

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildContainer({bool isMultiline = false, Widget? child, Widget? postWidget, Widget? preWidget, VoidCallback? onTap, VoidCallback? onClear, bool showClearButton = false, bool block = true, bool focusOnTap = true}) Widget
Builds the container structure for the input field.
inherited
buildTextController() TextEditingController
Creates specific controller for the text field.
buildTextField({int maxLines = 1, TextInputType? keyboardType, TextInputAction? textInputAction, List<TextInputFormatter>? inputFormatters, ValueChanged<String>? onValueChanged}) TextField
Builds the text field widget.
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant W oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFocusChanged(bool hasFocus) → void
Callback called when focus state changes.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited