expandedIconBackgroundColor property
Background color of the leading icon container when expanded/active.
Implementation
final Color? expandedIconBackgroundColor;
Background color of the leading icon container when expanded/active.
final Color? expandedIconBackgroundColor;