hoveredIconBackgroundColor property
Background color of the leading icon container when hovered.
Implementation
final Color? hoveredIconBackgroundColor;
Background color of the leading icon container when hovered.
final Color? hoveredIconBackgroundColor;