subtitleStyle property
Text style for the subtitle. Merged on top of default sizing style if provided.
Implementation
final TextStyle? subtitleStyle;
Text style for the subtitle. Merged on top of default sizing style if provided.
final TextStyle? subtitleStyle;