TTimelineLineStyle enum

The style of the connecting line.

Inheritance
Available extensions

Values

dashed → const TTimelineLineStyle

A dashed line consisting of dashes separated by gaps.

solid → const TTimelineLineStyle

A continuous solid line.

dotted → const TTimelineLineStyle

A dotted line made of small dots.

none → const TTimelineLineStyle

No line is drawn.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TTimelineLineStyle>
A constant List of the values in this enum, in order of their declaration.