indicatorAlignment property
Alignment of the indicator relative to the content column.
Implementation
final TTimelineIndicatorAlignment indicatorAlignment;
Alignment of the indicator relative to the content column.
final TTimelineIndicatorAlignment indicatorAlignment;