showScrollbar property
Whether to display a visible scrollbar when scrollable is true. Defaults to false.
Implementation
final bool showScrollbar;
Whether to display a visible scrollbar when scrollable is true. Defaults to false.
final bool showScrollbar;