lineStyle property
Custom line style for the connecting line following this item (dashed, solid, dotted, none).
Implementation
final TTimelineLineStyle? lineStyle;
Custom line style for the connecting line following this item (dashed, solid, dotted, none).
final TTimelineLineStyle? lineStyle;