TTourController class

Controller to drive a TTour walkthrough programmatically.

Inheritance

Constructors

TTourController()

Properties

currentStep → int
no setter
currentStepData → TTourStep?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isActive → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepCount → int
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
finish() → void
next() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previous() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
skip() → void
start(List<TTourStep> steps, {int initialStep = 0}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited