itemLabel property
Function to extract the display string for an item. Defaults to item.toString().
Implementation
final String Function(T item)? itemLabel;
Function to extract the display string for an item. Defaults to item.toString().
final String Function(T item)? itemLabel;