onSourceChanged property
Optional callback fired when the source items list changes.
Implementation
final ValueChanged<List<T>>? onSourceChanged;
Optional callback fired when the source items list changes.
final ValueChanged<List<T>>? onSourceChanged;