isLeafNode property
bool
get
isLeafNode
Whether this node has no children and is a leaf.
Implementation
bool get isLeafNode => isLeaf ?? children.isEmpty;
Whether this node has no children and is a leaf.
bool get isLeafNode => isLeaf ?? children.isEmpty;