textStyle property
Text style for the watermark. If null, a subtle dimmed style is derived from the theme.
Implementation
final TextStyle? textStyle;
Text style for the watermark. If null, a subtle dimmed style is derived from the theme.
final TextStyle? textStyle;