TPopupConstraints class
Constructors
- TPopupConstraints({required Size screenSize, required Size targetSize, required Offset targetOffset, required BoxConstraints contentBox, required Alignment contentAlignment})
-
const
- TPopupConstraints.calculate(BuildContext context, {required Size targetSize, required Matrix4 transform, required BoxConstraints inputConstraints, Alignment? alignment, double defaultSize = 100.0})
-
factory
Properties
- contentAlignment → Alignment
-
final
- contentBox → BoxConstraints
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSize → Size
-
final
- targetOffset → Offset
-
final
- targetSize → Size
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited