TAlertController class
Service for displaying alert dialogs.
TAlertService provides static methods to show varying types of alerts:
- Info, Success, Warning, Error
- Confirmations (Archive, Restore, Delete)
- Custom alerts with
showController for managing alert dialogs programmatically.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void - Closes the alert dialog if it is currently showing.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited