TAvatar class

An avatar widget that displays an image, initials, or a fallback icon.

TAvatar provides a flexible way to represent users or entities with:

  • Support for image URLs
  • Automatic initials generation from names
  • Custom shapes (circle, rounded rectangle)
  • Standardized sizes
  • Background colors for initials
  • Optional badge support

Basic Usage

TAvatar(
  url: 'https://example.com/avatar.jpg',
  name: 'John Doe',
  size: TInputSize.md,
)

With Initials

TAvatar(
  name: 'Jane Smith',
  backgroundColor: Colors.blue,
)
Inheritance
Available extensions

Constructors

TAvatar({Key? key, String? url, String? name, TInputSize size = TInputSize.md, BoxShape shape = BoxShape.circle, BorderRadius? borderRadius, Color? backgroundColor, Color? foregroundColor, String? title, String? subTitle, Color? titleColor, Color? subTitleColor, double spacing = 8})
Creates an avatar.
const
TAvatar.square({Key? key, String? url, String? name, TInputSize size = TInputSize.md, BorderRadius? borderRadius = const BorderRadius.all(Radius.circular(8)), Color? backgroundColor, Color? foregroundColor, String? title, String? subTitle, Color? titleColor, Color? subTitleColor, double spacing = 8})
Creates a square (rounded) avatar.
const

Properties

backgroundColor → Color?
The background color when displaying initials or the fallback icon.
final
borderRadius → BorderRadius?
The border radius for BoxShape.rectangle.
final
foregroundColor → Color?
The color of the initials text or fallback icon.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
name → String?
The name used to generate initials if url is null or fails to load.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → BoxShape
The shape of the avatar.
final
size → TInputSize
The size of the avatar.
final
spacing → double
Spacing between the avatar and the text.
final
subTitle → String?
Optional subtitle text displayed below the title.
final
subTitleColor → Color?
Custom color for the subtitle text.
final
title → String?
Optional title text displayed next to the avatar.
final
titleColor → Color?
Custom color for the title text.
final
url → String?
The URL of the avatar image.
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
center({bool when = true}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) → Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) → Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) → bool
The equality operator.
inherited