TBottomBar class
A highly customizable bottom navigation bar.
TBottomBar supports different text positions and visual variants
for the active item highlight.
Usage
TBottomBar(
currentIndex: _index,
onTap: (index) => setState(() => _index = index),
items: [
TBottomBarItem(icon: Icons.home, label: 'Home'),
TBottomBarItem(icon: Icons.search, label: 'Search'),
TBottomBarItem(icon: Icons.person, label: 'Profile'),
],
variant: TVariant.tonal,
textPosition: TBottomBarTextPosition.rightActive,
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TBottomBar
- Available extensions
Constructors
-
TBottomBar({Key? key, required List<
TBottomBarItem> items, required int currentIndex, ValueChanged<int> ? onTap, TVariant variant = TVariant.tonal, TBottomBarTextPosition textPosition = TBottomBarTextPosition.rightActive, Color? color, Color? background, EdgeInsets? padding = const EdgeInsets.symmetric(horizontal: 8, vertical: 8), EdgeInsets? margin, double? borderRadius, double? height, TextStyle? textStyle, double iconSize = 24, EdgeInsets itemPadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 8)}) -
Creates a bottom bar.
const
Properties
- background → Color?
-
The background color of the bottom bar.
final
- borderRadius → double?
-
The border radius of the active item highlight.
final
- color → Color?
-
The primary color used for the active item highlight.
Defaults to the theme's primary color.
final
- currentIndex → int
-
The index of the currently active item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the bottom bar.
final
- iconSize → double
-
final
- itemPadding → EdgeInsets
-
final
-
items
→ List<
TBottomBarItem> -
The list of items to display in the bottom bar.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsets?
-
The margin around the bottom bar.
final
-
onTap
→ ValueChanged<
int> ? -
Callback fired when an item is tapped.
final
- padding → EdgeInsets?
-
The padding around the bottom bar content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textPosition → TBottomBarTextPosition
-
The position and visibility of the labels.
final
- textStyle → TextStyle?
-
final
- variant → TVariant
-
The visual variant for the active item's highlight.
final
Methods
-
box(
{double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a ConstrainedBox to apply layout constraints. -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
center(
{bool when = true}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Center widget. -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in an Expanded widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padding(
[double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with flexible edge control. -
paddingSymmetric(
{double h = 0.0, double v = 0.0}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with symmetric horizontal and vertical spacing. -
size(
{double? w, double? h}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a SizedBox to apply fixed width and/or height. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
visible(
bool visible, {bool maintainState = false}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Visibility widget. -
when(
bool condition) → Widget -
Available on Widget, provided by the WidgetX extension
Returns this widget ifconditionis true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited