TButtonTheme class

Theme configuration for TButton.

Annotations

Constructors

TButtonTheme({required TWidgetTheme baseTheme, required TSize size, required TButtonShape shape, required ButtonStyle buttonStyle, double? scaleOnPress = 0.95})
const
TButtonTheme.defaultTheme(ColorScheme colors, {TVariant type = TVariant.solid, TButtonShape shape = TButtonShape.normal, TSize size = TSize.md})
factory

Properties

baseTheme → TWidgetTheme
final
buttonStyle → ButtonStyle
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleOnPress → double?
final
shape → TButtonShape
final
size → TSize
final

Methods

copyWith({TWidgetTheme? baseTheme, TSize? size, TButtonShape? shape, ButtonStyle? buttonStyle, double? scaleOnPress}) → TButtonTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildButtonStyle(TWidgetTheme baseTheme, TButtonShape shape, TSize size) → ButtonStyle