TCheckboxGroup<T> class

A group of checkboxes for multiple selection.

TCheckboxGroup provides a multi-select input with:

  • Multiple checkbox selection
  • Keyboard navigation support
  • Validation support
  • Vertical or horizontal layout
  • Value binding with ValueNotifier

Basic Usage

TCheckboxGroup<String>(
  label: 'Select options',
  items: [
    TCheckboxGroupItem(value: 'option1', label: 'Option 1'),
    TCheckboxGroupItem(value: 'option2', label: 'Option 2'),
    TCheckboxGroupItem(value: 'option3', label: 'Option 3'),
  ],
  onValueChanged: (values) => print('Selected: \$values'),
)

With Validation

TCheckboxGroup<String>(
  label: 'Select at least one',
  isRequired: true,
  items: items,
  rules: [
    (values) => values == null || values.isEmpty
        ? 'Please select at least one option'
        : null,
  ],
)

Type parameter:

  • T: The type of values for the checkboxes

See also:

Inheritance
Mixed-in types
Available extensions

Constructors

TCheckboxGroup({Key? key, String? label, String? tag, String? helperText, String? info, bool isRequired = false, bool disabled = false, bool clearable = false, TInputFieldTheme? theme, VoidCallback? onTap, FocusNode? focusNode, List<T>? value, ValueNotifier<List<T>?>? valueNotifier, ValueChanged<List<T>?>? onValueChanged, List<String? Function(List<T>?)>? rules, Duration? validationDebounce, List<TCheckboxGroupItem<T>> items = const [], Color? color, bool block = true, bool vertical = false, bool autoFocus = false, double spacing = 16, double runSpacing = 8})
Creates a checkbox group.
const

Properties

autoFocus bool
Whether to auto-focus the first checkbox.
final
block bool
Whether to display in block mode.
final
clearable bool
Whether the field shows a clear button when it has a value.
final
color Color?
Custom color for the checkboxes.
final
disabled bool
Whether the field is disabled.
final
focusNode FocusNode?
Custom focus node.
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
The helper text.
final
info String?
The info text (optional).
final
isRequired bool
Whether the field is required.
final
items List<TCheckboxGroupItem<T>>
The list of checkbox items.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
The label text.
final
onTap VoidCallback?
Callback for tap events.
final
onValueChanged ValueChanged<List<T>?>?
Callback fired when the value changes.
final
rules List<String? Function(List<T>?)>?
List of validation rules.
final
runSpacing double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final
tag String?
The tag text (optional).
final
theme TInputFieldTheme?
Custom theme.
final
validationDebounce Duration?
Debounce duration for validation trigger.
final
value List<T>?
The initial value.
final
valueNotifier ValueNotifier<List<T>?>?
A ValueNotifier for two-way binding.
final
vertical bool
Whether to display vertically.
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
center({bool when = true}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TCheckboxGroup<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
validateValue(List<T>? value) List<String>
Validates the given value against the rules.
inherited
visible(bool visible, {bool maintainState = false}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) bool
The equality operator.
inherited