TCommandGroup class
A section of related commands in a TCommandPalette.
Constructors
-
TCommandGroup({required String heading, required List<
TCommandItem> items}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → String
-
Group header title (e.g. 'NAVIGATION', 'QUICK ACTIONS').
final
-
items
→ List<
TCommandItem> -
The list of command items in this group.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited