storageKey property
Optional unique key to identify and persist table layout settings (dense layout, view mode). If null, settings are automatically persisted by the current route name.
Implementation
final String? storageKey;
Optional unique key to identify and persist table layout settings (dense layout, view mode). If null, settings are automatically persisted by the current route name.
final String? storageKey;