TCsvEditor constructor
const
TCsvEditor({
- Key? key,
- required List<
TCsvColumn> columns, - List<
Map< ? initialData,String, dynamic> > - Future<
void> onSave()?, - ValueChanged<
List< ? onDataChanged,Map< >String, dynamic> > - String? title = 'CSV Data Editor',
- String? subtitle = 'Upload a CSV file or add rows manually to review and edit data.',
- String saveButtonText = 'Upload Data',
- IconData saveButtonIcon = Icons.cloud_upload_outlined,
- bool showDownloadTemplate = true,
- bool showExport = true,
- bool allowAddRow = true,
- bool allowDeleteRow = true,
- bool allowDuplicateRow = true,
- bool allowPaste = true,
- bool autoPromptMappingOnDiff = true,
- TCsvEditorTheme? theme,
- int itemsPerPage = 20,
Implementation
const TCsvEditor({
super.key,
required this.columns,
this.initialData,
this.onSave,
this.onDataChanged,
this.title = 'CSV Data Editor',
this.subtitle = 'Upload a CSV file or add rows manually to review and edit data.',
this.saveButtonText = 'Upload Data',
this.saveButtonIcon = Icons.cloud_upload_outlined,
this.showDownloadTemplate = true,
this.showExport = true,
this.allowAddRow = true,
this.allowDeleteRow = true,
this.allowDuplicateRow = true,
this.allowPaste = true,
this.autoPromptMappingOnDiff = true,
this.theme,
this.itemsPerPage = 20,
});