TCsvEditorTheme class
Theme configuration for TCsvEditor.
Constructors
- TCsvEditorTheme({EdgeInsetsGeometry padding = const EdgeInsets.all(16), double? tableMaxHeight, double dropzoneHeight = 160, bool dense = true, Color? dropzoneColor, Color? dropzoneBorderColor})
-
const
Properties
- dense → bool
-
Whether the inline table cells should use compact/dense padding.
final
- dropzoneBorderColor → Color?
-
Custom border color for the dropzone upload area.
final
- dropzoneColor → Color?
-
Custom background color for the dropzone upload area.
final
- dropzoneHeight → double
-
Height of the dropzone file input area.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsetsGeometry
-
Padding around the editor container.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableMaxHeight → double?
-
Maximum height of the data table area.
final
Methods
-
copyWith(
{EdgeInsetsGeometry? padding, double? tableMaxHeight, double? dropzoneHeight, bool? dense, Color? dropzoneColor, Color? dropzoneBorderColor}) → TCsvEditorTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited