TCsvParseResult class
Structured result of parsing CSV, TSV, DSV, or JSON data.
Constructors
Properties
- delimiter → String?
-
Effective delimiter used (null if JSON).
final
- format → TCsvFileFormat
-
Detected file or data format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
String> -
Extracted column headers / JSON object keys.
final
- isEmpty → bool
-
no setter
- isNotEmpty → bool
-
no setter
-
jsonMaps
→ List<
Map< ?String, dynamic> > -
Original JSON maps if parsed from a JSON payload.
final
-
rows
→ List<
List< String> > -
Stringified table row cells:
List<List<String>>.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited