TCsvParser class
Robust parser and generator for CSV / TSV data.
Compliant with RFC-4180, supporting:
- Quoted cells with commas and escaped quotes (
""). - Multiline quoted cells.
- Auto-detection of delimiters (
,,;,\t,|). - Byte Order Mark (BOM) stripping.
- Template generation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
detectDelimiter(
String content) → String - Auto-detects the most likely delimiter from CSV content.
-
generateTemplate(
List< TCsvColumn> columns, {bool includeSampleRow = true, String delimiter = ','}) → String - Generates a sample CSV template string based on a list of TCsvColumns.
-
parse(
String content, {String? delimiter}) → List< List< String> > -
Parses CSV / TSV text content into a list of row cells:
List<List<String>>. -
toCsv(
List< String> headers, List<List> rows, {String delimiter = ','}) → String - Converts headers and rows to a standard CSV formatted string.