TDropdownTheme class

Inheritance

Constructors

TDropdownTheme({required Color defaultColor, required Color hoverColor, required Color activeColor, required Color activeBackgroundColor, required Color borderColor, Duration animationDuration = const Duration(milliseconds: 200), Duration showDelay = const Duration(milliseconds: 25), Duration hideDelay = const Duration(milliseconds: 125), TPopupAlignment alignment = TPopupAlignment.bottomLeft, double offset = 8.0, TPopupAlignment secondaryAlignment = TPopupAlignment.rightTop, double secondaryOffset = 8.0, BoxConstraints boxConstraints = const BoxConstraints(minWidth: 175), double iconSize = 20.0, double arrowIconSize = 11.0, double gap = 10.0, double overlayElevation = 8.0, BorderRadius overlayBorderRadius = const BorderRadius.all(Radius.circular(8.0)), EdgeInsets overlayPadding = const EdgeInsets.symmetric(vertical: 8), EdgeInsets itemPadding = const EdgeInsets.symmetric(horizontal: 16, vertical: 12), BorderRadius itemBorderRadius = const BorderRadius.all(Radius.circular(6.0)), double fontSize = 14.0, FontWeight fontWeight = FontWeight.w300, IconData? arrowIcon, IconData? dropdownIcon, IconData? expandIcon})
const
TDropdownTheme.defaultTheme(ColorScheme? colors)
factory

Properties

activeBackgroundColor → Color
finalinherited
activeColor → Color
finalinherited
alignment → TPopupAlignment
finalinherited
animationDuration → Duration
finalinherited
arrowIcon → IconData?
finalinherited
arrowIconSize → double
finalinherited
borderColor → Color
finalinherited
boxConstraints → BoxConstraints
finalinherited
defaultColor → Color
finalinherited
finalinherited
expandIcon → IconData?
finalinherited
fontSize → double
finalinherited
fontWeight → FontWeight
finalinherited
gap → double
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hideDelay → Duration
finalinherited
hoverColor → Color
finalinherited
iconSize → double
finalinherited
itemBorderRadius → BorderRadius
finalinherited
itemPadding → EdgeInsets
finalinherited
offset → double
finalinherited
overlayBorderRadius → BorderRadius
finalinherited
overlayElevation → double
finalinherited
overlayPadding → EdgeInsets
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryAlignment → TPopupAlignment
finalinherited
secondaryOffset → double
finalinherited
showDelay → Duration
finalinherited

Methods

copyWith({Color? defaultColor, Color? hoverColor, Color? activeColor, Color? activeBackgroundColor, Color? borderColor, Duration? animationDuration, Duration? showDelay, Duration? hideDelay, TPopupAlignment? alignment, double? offset, TPopupAlignment? secondaryAlignment, double? secondaryOffset, BoxConstraints? boxConstraints, double? iconSize, double? arrowIconSize, double? gap, double? overlayElevation, BorderRadius? overlayBorderRadius, EdgeInsets? overlayPadding, EdgeInsets? itemPadding, BorderRadius? itemBorderRadius, double? fontSize, FontWeight? fontWeight, IconData? arrowIcon, IconData? dropdownIcon, IconData? expandIcon}) → TDropdownTheme
override
getItemColor({required bool isActive, required bool containsActive, required bool isHovered}) → Color
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited