TEmptyState.noData constructor
const
TEmptyState.noData({
- Key? key,
- dynamic icon = Icons.inbox_outlined,
- Widget? image,
- String? title = 'No data available',
- Widget? titleWidget,
- String? description = 'There are no records to display at this time.',
- Widget? descriptionWidget,
- Widget? action,
- Widget? secondaryAction,
- bool compact = false,
- EdgeInsetsGeometry padding = const EdgeInsets.all(32.0),
- Color? iconColor,
- Color? iconBackgroundColor,
- double? iconSize,
Creates a standard "No Data" placeholder.
Implementation
const TEmptyState.noData({
super.key,
this.icon = Icons.inbox_outlined,
this.image,
this.title = 'No data available',
this.titleWidget,
this.description = 'There are no records to display at this time.',
this.descriptionWidget,
this.action,
this.secondaryAction,
this.compact = false,
this.padding = const EdgeInsets.all(32.0),
this.iconColor,
this.iconBackgroundColor,
this.iconSize,
});