TEmptyState.notFound constructor
const
TEmptyState.notFound({
- Key? key,
- dynamic icon = Icons.find_in_page_outlined,
- Widget? image,
- String? title = 'Item Not Found',
- Widget? titleWidget,
- String? description = 'The item or resource you requested could not be located.',
- Widget? descriptionWidget,
- Widget? action,
- Widget? secondaryAction,
- bool compact = false,
- EdgeInsetsGeometry padding = const EdgeInsets.all(32.0),
- Color? iconColor,
- Color? iconBackgroundColor,
- double? iconSize,
Creates a 404 or missing resource empty state.
Implementation
const TEmptyState.notFound({
super.key,
this.icon = Icons.find_in_page_outlined,
this.image,
this.title = 'Item Not Found',
this.titleWidget,
this.description = 'The item or resource you requested could not be located.',
this.descriptionWidget,
this.action,
this.secondaryAction,
this.compact = false,
this.padding = const EdgeInsets.all(32.0),
this.iconColor,
this.iconBackgroundColor,
this.iconSize,
});