TError class
Represents parsed error details.
Constructors
Properties
-
errors
→ Map<
String, List< ?String> > -
Map of field keys to lists of error messages.
final
- hasError → bool
-
Returns true if there is a main error message or field error map.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
The main error message title.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited