widgets/form/form_builder library

Classes

TFieldProp<T>
A reactive property for form fields with subscription support.
TFormBase
Base class for creating structured forms.
TFormBuilder
A responsive form builder with grid layout.
TFormField<T>
A form field wrapper with factory methods for all input types.