footer property
Widget?
get
footer
Optional footer widget to display at the bottom of the form.
Can be used to display additional information, warnings, summary statistics, or dynamic/computed values based on form field inputs.
Implementation
Widget? get footer => null;