TFormBuilder class

A responsive form builder with grid layout.

TFormBuilder provides automatic form layout with:

  • 12-column responsive grid system
  • Automatic field sizing based on breakpoints
  • Integration with TFormBase
  • Nested form support

Basic Usage

class UserForm extends TFormBase {
  final name = TFieldProp<String>('');
  final email = TFieldProp<String>('');

  @override
  List<TFormField> get fields => [
    TFormField.text(name, 'Name').size(6),
    TFormField.text(email, 'Email').size(6),
  ];
}

TFormBuilder(input: UserForm())

See also:

Inheritance
Available extensions

Constructors

TFormBuilder({Key? key, TFormBase? input, List<TFormField>? fields, double gapX = 16.0, double gapY = 26.0, VoidCallback? onValueChanged, IconData? icon, String? label, String? description, bool initiallyExpanded = false})
Creates a form builder.
const

Properties

description String?
Optional sub title for the form.
final
fields List<TFormField>?
Manual list of fields (alternative to input).
final
gapX double
Horizontal spacing between fields.
final
gapY double
Vertical spacing between fields.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
initiallyExpanded bool
final
input TFormBase?
The form model to build.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Optional title for the form.
final
onValueChanged VoidCallback?
Callback fired when any field value changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
center({bool when = true}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) bool
The equality operator.
inherited