TItemsFormBuilder<T extends TFormBase> class
A dynamic form builder for managing lists of sub-forms.
TItemsFormBuilder provides dynamic list management with:
- Add/remove items dynamically
- Each item is a complete form (TFormBase)
- Configurable add button position
- Automatic value synchronization
Usage Example
class AddressForm extends TFormBase {
final street = TFieldProp<String>('');
final city = TFieldProp<String>('');
@override
List<TFormField> get fields => [
TFormField.text(street, 'Street'),
TFormField.text(city, 'City'),
];
}
final addresses = TFieldProp<List<AddressForm>>([]);
TFormField.items(
addresses,
() => AddressForm(),
label: 'Addresses',
buttonLabel: 'Add Address',
)
Type parameter:
T: The form type (must extend TFormBase)
See also:
- TFormBase for form models
- TFormField.items for field creation
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TItemsFormBuilder
- Mixed-in types
-
- TInputValueMixin<
List< T> >
- TInputValueMixin<
- Available extensions
Constructors
-
TItemsFormBuilder({Key? key, List<
T> ? value, ValueChanged<List< ? onValueChanged, ValueNotifier<T> ?>List< ? valueNotifier, required T onNewItem(), String? label, String buttonLabel = 'Add New', TItemAddPosition itemAddPosition = TItemAddPosition.first})T> ?> -
Creates an items form builder.
const
Properties
-
Label for the add button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemAddPosition → TItemAddPosition
-
Where to add new items (first or last).
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Optional label for the form list.
final
- onNewItem → T Function()
-
Factory function to create new items.
final
-
onValueChanged
→ ValueChanged<
List< ?T> ?> -
Callback fired when the value changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ List<
T> ? -
The initial value.
final
-
valueNotifier
→ ValueNotifier<
List< ?T> ?> -
A ValueNotifier for two-way binding.
final
Methods
-
box(
{double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a ConstrainedBox to apply layout constraints. -
center(
{bool when = true}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Center widget. -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TItemsFormBuilder< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in an Expanded widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padding(
[double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with flexible edge control. -
paddingSymmetric(
{double h = 0.0, double v = 0.0}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with symmetric horizontal and vertical spacing. -
size(
{double? w, double? h}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a SizedBox to apply fixed width and/or height. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
visible(
bool visible, {bool maintainState = false}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Visibility widget. -
when(
bool condition) → Widget -
Available on Widget, provided by the WidgetX extension
Returns this widget ifconditionis true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited