TGridSize class

Defines the column span of a component at different breakpoints.

Constructors

TGridSize({int? sm, int? md, int? lg})
Creates a responsive grid size.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg int?
Span at large screens
final
md int?
Span at medium screens
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm int?
Span at small screens
final

Methods

getSpan(TBreakpoint bp) int
Gets the span for a specific breakpoint, falling back to smaller sizes or 12 (full width).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited