TGridSize class
Defines the column span of a component at different breakpoints.
Properties
Methods
-
getSpan(
TBreakpoint bp) → int - Gets the span for a specific breakpoint, falling back to smaller sizes or 12 (full width).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited