aspectRatio property
The aspect ratio of the image (width / height).
When used with width, height is computed as width / aspectRatio.
When used with height, width is computed as height * aspectRatio.
When used with size, height is computed as size / aspectRatio.
Implementation
final double? aspectRatio;