TKeyValue class
Represents a single key-value item in a TKeyValueSection.
Constructors
- TKeyValue(String key, {String? value, Widget? widget, double? width, Alignment? alignment, double? minWidth, double? maxWidth})
- Creates a key-value item.
- TKeyValue.text(String key, String? value, {Alignment? alignment, double? minWidth, double? maxWidth})
-
Creates a key-value item with text value.
factory
Properties
- alignment → Alignment?
-
Optional alignment for the item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The label/key text.
final
- maxWidth → double?
-
Optional maximum width for the item.
final
- minWidth → double?
-
Optional minimum width for the item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
The value text.
final
- widget → Widget?
-
Custom widget to display instead of text value.
final
- width → double?
-
Optional fixed width for the column.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
mapHeaders<
T, K> (BuildContext ctx, List< TTableHeader< headers, TListItem<T, K> >T, K> item, int index) → List<TKeyValue> - Maps table headers to key-value items for list view representation.