TKeyValueSection class

A responsive key-value display section.

TKeyValueSection provides adaptive layout for key-value pairs with:

  • Grid layout on wide screens
  • Key-value layout on narrow screens
  • Custom breakpoint control
  • Widget support for values

Basic Usage

TKeyValueSection(
  values: [
    TKeyValue(key: 'Name', value: 'John Doe'),
    TKeyValue(key: 'Email', value: 'john@example.com'),
    TKeyValue(key: 'Phone', value: '+1234567890'),
  ],
)

With Custom Widgets

TKeyValueSection(
  values: [
    TKeyValue(key: 'Status', widget: TChip(text: 'Active')),
    TKeyValue(key: 'Actions', widget: Row(children: [...])),
  ],
)

See also:

Inheritance
Available extensions

Constructors

TKeyValueSection({Key? key, required List<TKeyValue> values, TKeyValueTheme? theme, bool? forceKeyValue, bool? valueAfterKey, int? columns, bool? gridInline, bool? columnar, double? inlineKeyWidth, double? inlineKeyMaxWidth, Alignment? inlineKeyAlignment, double? inlineKeyGap, double? gridHorizontalSpacing, double? gridVerticalSpacing, double? gridCellGap, double? hSpacing, double? vSpacing, double? gap})
const
TKeyValueSection.columnsInline({Key? key, required List<TKeyValue> values, TKeyValueTheme? theme, int? columns, double? keyWidth, double? keyMaxWidth, double gap = 8, Alignment? keyAlignment, double hSpacing = 24, double vSpacing = 12})
Factory constructor for inline multi-column grid layout with vertically aligned key columns.
factory
TKeyValueSection.columnsStacked({Key? key, required List<TKeyValue> values, TKeyValueTheme? theme, int? columns, double gap = 4, double hSpacing = 20, double vSpacing = 14})
Factory constructor for stacked multi-column grid layout with uniform/proportional columns.
factory
TKeyValueSection.flow({Key? key, required List<TKeyValue> values, TKeyValueTheme? theme, double gap = 8, double hSpacing = 20, double vSpacing = 12})
Factory constructor for inline dynamic flow layout where Key: Value items wrap naturally based on width.
factory
TKeyValueSection.flowStacked({Key? key, required List<TKeyValue> values, TKeyValueTheme? theme, double gap = 4, double hSpacing = 16, double vSpacing = 12})
Factory constructor for stacked dynamic flow layout where keys are stacked above values and wrap naturally based on width.
factory
TKeyValueSection.split({Key? key, required List<TKeyValue> values, TKeyValueTheme? theme, bool valueAfterKey = false, double gap = 8, double vSpacing = 10})
Factory constructor for split single-column layout (Key on far left, Value on far right).
factory

Properties

columnar bool?
final
columns int?
final
forceKeyValue bool?
final
gridCellGap double?
final
gridHorizontalSpacing double?
final
gridInline bool?
final
gridVerticalSpacing double?
final
hashCode int
The hash code for this object.
no setterinherited
inlineKeyAlignment Alignment?
final
inlineKeyGap double?
final
inlineKeyMaxWidth double?
final
inlineKeyWidth double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme TKeyValueTheme?
final
valueAfterKey bool?
final
values List<TKeyValue>
final

Methods

box({double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a ConstrainedBox to apply layout constraints.
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
center({bool when = true}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Center widget.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in an Expanded widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padding([double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with flexible edge control.
paddingSymmetric({double h = 0.0, double v = 0.0}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Padding with symmetric horizontal and vertical spacing.
size({double? w, double? h}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a SizedBox to apply fixed width and/or height.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool visible, {bool maintainState = false}) Widget

Available on Widget, provided by the WidgetX extension

Wraps this widget in a Visibility widget.
when(bool condition) Widget

Available on Widget, provided by the WidgetX extension

Returns this widget if condition is true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)

Operators

operator ==(Object other) bool
The equality operator.
inherited