TKeyValueSection.flowStacked constructor
TKeyValueSection.flowStacked({})
Factory constructor for stacked dynamic flow layout where keys are stacked above values and wrap naturally based on width.
Implementation
factory TKeyValueSection.flowStacked({
Key? key,
required List<TKeyValue> values,
TKeyValueTheme? theme,
double gap = 4,
double hSpacing = 16,
double vSpacing = 12,
bool? removeEmpty,
}) {
return TKeyValueSection(
key: key,
values: values,
theme: theme,
gridInline: false,
columnar: false,
gridCellGap: gap,
gridHorizontalSpacing: hSpacing,
gridVerticalSpacing: vSpacing,
removeEmpty: removeEmpty,
);
}