TKeyValueMode enum
Defines the layout presentation mode for TKeyValueSection.
Values
- stackedFlow → const TKeyValueMode
-
Items flow dynamically into rows based on natural width, with keys stacked above values.
- stackedColumns → const TKeyValueMode
-
Items are arranged in uniform grid columns, with keys stacked above values.
- inlineFlow → const TKeyValueMode
-
Items flow dynamically into rows based on natural width, with keys and values inline (
Key: Value). - inlineColumns → const TKeyValueMode
-
Items are arranged in uniform grid columns with aligned keys and values inline (
Key: Value). - split → const TKeyValueMode
-
Single-column layout with key on the far left and value on the far right.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isColumnar → bool
-
Whether items are arranged in uniform multi-column grid layout.
no setter
- isFlow → bool
-
Whether items wrap and flow dynamically based on natural content width.
no setter
- isInline → bool
-
Whether keys and values are displayed side-by-side inline (
Key: Value).no setter - isSplit → bool
-
Whether items are in single-column split mode.
no setter
- isStacked → bool
-
Whether keys are stacked vertically above values.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TKeyValueMode> - A constant List of the values in this enum, in order of their declaration.