TKeyValueTheme class

Theme configuration for TKeyValueSection.

TKeyValueTheme controls the appearance of key-value pairs, including:

  • Text styles for keys, labels, and values
  • Grid layout spacing and breakpoints
Implementers

Constructors

TKeyValueTheme({required TextStyle keyStyle, required TextStyle labelStyle, required TextStyle valueStyle, double gridSpacing = 0, double minGridColWidth = 110, bool forceKeyValue = false, double keyValueBreakPoint = 350})
Creates a key-value theme.
const
TKeyValueTheme.defaultTheme(ColorScheme colors)
factory

Properties

forceKeyValue bool
final
gridSpacing double
final
hashCode int
The hash code for this object.
no setterinherited
keyStyle TextStyle
final
keyValueBreakPoint double
final
labelStyle TextStyle
final
minGridColWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueStyle TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited