TListControllerActions<T, K> extension
Extension providing error handling, item editing/creation, and additional state actions for TListController.
- on
-
- TListController<
T, K>
- TListController<
Methods
-
beginCreateItem(
{bool clearEditingItem = true}) → void -
Available on TListController<
Puts the list into a state ready to create a new item.T, K> , provided by the TListControllerActions extension -
beginEditItem(
T item) → void -
Available on TListController<
Puts the list into a state ready to edit an item.T, K> , provided by the TListControllerActions extension -
beginEditItemKey(
K key) → void -
Available on TListController<
Puts the list into a state ready to edit an item key.T, K> , provided by the TListControllerActions extension -
cancelCreateItem(
) → void -
Available on TListController<
Cancels the create item state.T, K> , provided by the TListControllerActions extension -
cancelEditItem(
) → void -
Available on TListController<
Cancels the edit item state.T, K> , provided by the TListControllerActions extension -
cancelPendingOperations(
) → void -
Available on TListController<
Cancels all pending debouncer timers and network requests.T, K> , provided by the TListControllerActions extension -
clearAdditionalState(
) → void -
Available on TListController<
Clears the additional state and notifies listeners.T, K> , provided by the TListControllerActions extension -
clearError(
) → void -
Available on TListController<
Clears any error state.T, K> , provided by the TListControllerActions extension -
handleError(
TListError error) → void -
Available on TListController<
Sets an error state on the list.T, K> , provided by the TListControllerActions extension -
setAdditionalState(
String key, dynamic value) → void -
Available on TListController<
Sets a value in the additional state and notifies listeners if it changed.T, K> , provided by the TListControllerActions extension -
updateError(
Object e, StackTrace st) → void -
Available on TListController<
Helper to wrap exception and stacktrace into a TListError.T, K> , provided by the TListControllerActions extension -
updateLoading(
) → void -
Available on TListController<
Puts the list into a loading state.T, K> , provided by the TListControllerActions extension