TListItem<T, K> class
Constructors
Properties
- childCount → int
-
no setter
-
childrenKeys
→ List<
K> ? -
final
- data → T
-
final
- hasChildren → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → K
-
final
- level → int
-
final
- parentKey → K?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{T? data, K? parentKey, List< K> ? childrenKeys, int? level}) → TListItem<T, K> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override