TListState<T, K> class
Constructors
-
TListState({required LinkedHashSet<K> selectedKeys, required LinkedHashSet<K> expandedKeys, required List<TListItem<T, K>> displayItems, required int page, required int itemsPerPage, required int totalItems, required bool loading, required bool fetching, required bool hasMoreItems, required String search, TListError? error, K? expandedDetailKey, K? editingItemKey, bool isCreatingItem = false, String? currentCursor, String? nextCursor, List<String> cursorHistory = const [], Map<String, dynamic>? advancedSearch, Map<String, dynamic> additional = const {}})
-
const
Methods
-
copyWith({LinkedHashSet<K>? selectedKeys, LinkedHashSet<K>? expandedKeys, List<TListItem<T, K>>? displayItems, int? page, int? itemsPerPage, int? totalItems, bool? loading, bool? fetching, bool? hasMoreItems, String? search, TListError? error, K? expandedDetailKey, K? editingItemKey, bool? isCreatingItem, String? currentCursor, String? nextCursor, List<String>? cursorHistory, Map<String, dynamic>? advancedSearch, Map<String, dynamic>? additional})
→ TListState<T, K>
-
Creates a copy of this state with the given fields updated.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override