TListState<T, K> class

Constructors

TListState({required LinkedHashSet<K> selectedKeys, required LinkedHashSet<K> expandedKeys, required List<TListItem<T, K>> displayItems, required int page, required int itemsPerPage, required int totalItems, required bool loading, required bool fetching, required bool hasMoreItems, required String search, TListError? error, String? currentCursor, String? nextCursor, List<String> cursorHistory = const [], Map<String, dynamic>? advancedSearch})
const

Properties

advancedSearch Map<String, dynamic>?
final
currentCursor String?
final
cursorHistory List<String>
final
displayItems List<TListItem<T, K>>
final
error TListError?
final
expandedKeys LinkedHashSet<K>
final
fetching bool
final
hashCode int
The hash code for this object.
no setterinherited
hasMoreItems bool
final
itemsPerPage int
final
loading bool
final
nextCursor String?
final
page int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
selectedKeys LinkedHashSet<K>
final
totalItems int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited