TGooglePlaceDetailsResponse class
Response model for Google Place Details API.
Constructors
-
TGooglePlaceDetailsResponse({required String id, required String name, required String formattedAddress, LatLng? location, TGooglePredictionText? displayName, required Map<
String, dynamic> raw}) -
const
-
TGooglePlaceDetailsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- displayName → TGooglePredictionText?
-
final
- formattedAddress → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- location → LatLng?
-
final
- name → String
-
final
-
raw
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited