TMapPin class
Constructors
Properties
- alignment → Alignment?
-
final
- assetPath → String?
-
final
- coordinates → LatLng
-
final
- customBuilder → Widget? Function(BuildContext)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- iconColor → Color?
-
final
- infoWindowBuilder → Widget? Function(BuildContext)?
-
final
- label → String?
-
final
- labelColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited