TModal class
A customizable modal dialog component.
TModal provides a centered modal overlay with:
- Optional header and footer
- Scrollable content area
- Persistent or dismissible modes
- Custom width and sizing
- Close button support
Basic Usage
showDialog(
context: context,
builder: (context) => TModal(
Text('Modal content goes here'),
title: 'Modal Title',
showCloseButton: true,
onClose: () => Navigator.pop(context),
),
);
With Custom Header and Footer
showDialog(
context: context,
builder: (context) => TModal(
YourContentWidget(),
header: CustomHeaderWidget(),
footer: Row(
children: [
TButton(text: 'Cancel', onTap: () => Navigator.pop(context)),
TButton(text: 'Save', onTap: () => save()),
],
),
),
);
Persistent Modal
TModal(
YourContent(),
persistent: true, // Cannot be dismissed by tapping outside
title: 'Important',
showCloseButton: true,
)
See also:
- TAlert for simple alert dialogs
- Inheritance
- Available extensions
Constructors
Properties
- child → Widget
-
The content widget to display in the modal.
final
-
Custom footer widget.
final
- gap → double
-
Gap/margin around the modal.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
Custom header widget.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → VoidCallback?
-
Callback fired when the modal is closed.
final
- persistent → bool
-
Whether the modal is persistent (cannot be dismissed by tapping outside).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool?
-
Whether to show the close button in the default header.
final
- title → String?
-
The title text for the default header.
final
- width → double
-
The width of the modal.
final
Methods
-
box(
{double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a ConstrainedBox to apply layout constraints. -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
center(
{bool when = true}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Center widget. -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in an Expanded widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padding(
[double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with flexible edge control. -
paddingSymmetric(
{double h = 0.0, double v = 0.0}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with symmetric horizontal and vertical spacing. -
size(
{double? w, double? h}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a SizedBox to apply fixed width and/or height. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
visible(
bool visible, {bool maintainState = false}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Visibility widget. -
when(
bool condition) → Widget -
Available on Widget, provided by the WidgetX extension
Returns this widget ifconditionis true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited