TModalService class
Service for showing modal dialogs.
TModalService provides a simplified API for displaying TModal dialogs.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultAdaptiveLayoutBuilder(
BuildContext context, Widget child, {String? title, String? subTitle, String? imageUrl, String? description, VoidCallback? onBackPressed}) → Widget - Default layout builder for showAdaptive mobile (page push) mode.
-
show<
T> (BuildContext context, TModalWidgetBuilder< T> builder, {bool persistent = false, double? width, double? minWidth, double? minHeight, bool fullscreen = false, double gap = 50, String? title, bool? showCloseButton, Widget layoutBuilder(BuildContext context, Widget child)?}) → Future<T?> - Shows a modal dialog.
-
showAdaptive<
T> (BuildContext context, TModalWidgetBuilder< T> builder, {String? title, String? subTitle, String? imageUrl, String? description, bool persistent = false, double? width, bool? showCloseButton, Widget layoutBuilder(BuildContext context, Widget child)?}) → Future<T?> - Shows an adaptive modal dialog.