TSpeedDialChild class
A child action item in a TSpeedDial.
Constructors
- TSpeedDialChild({required IconData icon, required VoidCallback onTap, String? label, Color? backgroundColor, Color? foregroundColor})
-
const
Properties
- backgroundColor → Color?
-
Background color for this action button.
final
- foregroundColor → Color?
-
Foreground icon/text color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
The icon displayed inside this action button.
final
- label → String?
-
Optional label text displayed beside the button.
final
- onTap → VoidCallback
-
Callback when this child action is clicked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited