TSplitPaneController class
Controller for TSplitPane to programmatically control split ratio and collapse states.
- Inheritance
-
- Object
- ChangeNotifier
- TSplitPaneController
Constructors
- TSplitPaneController({double? initialRatio})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isLeadingCollapsed → bool
-
Whether the leading pane is currently collapsed.
no setter
- isTrailingCollapsed → bool
-
Whether the trailing pane is currently collapsed.
no setter
- leadingExtent → double?
-
Pixel extent of leading pane, if set in fixed pixels.
no setter
- ratio → double?
-
Current split ratio (0.0 to 1.0) representing the proportion of the leading pane.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
collapseLeading(
) → void - Collapse the leading pane.
-
collapseTrailing(
) → void - Collapse the trailing pane.
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
expand(
) → void - Expand and restore previously collapsed pane.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void - Reset the split pane to its initial configuration.
-
setLeadingExtent(
double extent) → void - Set the pixel extent for the leading pane.
-
setRatio(
double ratio) → void - Set the split ratio directly (clamped between 0.0 and 1.0).
-
toggleLeadingCollapse(
) → void - Toggle collapse for leading pane.
-
toggleTrailingCollapse(
) → void - Toggle collapse for trailing pane.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited