TStep class
A step in a TStepper.
Constructors
Properties
- color → Color?
-
Custom color for this step.
final
- content → Widget
-
The content of the step when it is active.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Optional icon to display instead of the step number.
final
- isActive → bool
-
Whether the step is currently active.
final
- isCompleted → bool
-
Whether the step is completed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → Widget?
-
The subtitle of the step.
final
- title → Widget
-
The title of the step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited