titleBelowIndicator property
When true in horizontal mode, the step title is placed below
the indicator instead of beside it — better suited for mobile layouts.
Implementation
final bool? titleBelowIndicator;
When true in horizontal mode, the step title is placed below
the indicator instead of beside it — better suited for mobile layouts.
final bool? titleBelowIndicator;