TTableMobileCardTheme class
Theme configuration for TTableMobileCard.
TTableMobileCardTheme extends TKeyValueTheme to style the mobile card
view of table rows. It adds card-specific properties like:
- Margins/Padding
- Elevation
- Border Radius
- Background and Border colors (normal/selected)
- Inheritance
-
- Object
- TKeyValueTheme
- TTableMobileCardTheme
Constructors
-
TTableMobileCardTheme({EdgeInsets margin = const EdgeInsets.only(bottom: 12), EdgeInsets padding = const EdgeInsets.all(16), double elevation = 1, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(12)), required WidgetStateProperty<
Color> backgroundColor, required WidgetStateProperty<Border> border, required TextStyle keyStyle, required TextStyle labelStyle, required TextStyle valueStyle, double gridSpacing = 0, double minGridColWidth = 110, bool forceKeyValue = false, double keyValueBreakPoint = 350}) -
Creates a mobile card theme.
const
- TTableMobileCardTheme.defaultTheme(ColorScheme colors)
-
factory
Properties
-
backgroundColor
→ WidgetStateProperty<
Color> -
final
-
border
→ WidgetStateProperty<
Border> -
final
- borderRadius → BorderRadius
-
final
- elevation → double
-
final
- forceKeyValue → bool
-
finalinherited
- gridSpacing → double
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyStyle → TextStyle
-
finalinherited
- keyValueBreakPoint → double
-
finalinherited
- labelStyle → TextStyle
-
finalinherited
- margin → EdgeInsets
-
final
- minGridColWidth → double
-
finalinherited
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueStyle → TextStyle
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited