TTableRowCardTheme class

Theme configuration for TTableRowCard.

TTableRowCardTheme styles the desktop/tablet row view in tables, including:

  • Margins/Padding
  • Elevation
  • Text content style
  • Background colors for rows

Constructors

TTableRowCardTheme({EdgeInsets margin = const EdgeInsets.only(bottom: 8), EdgeInsets padding = const EdgeInsets.symmetric(vertical: 12, horizontal: 16), double elevation = 1, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8)), required WidgetStateProperty<Color> backgroundColor, required WidgetStateProperty<Border> border, required TextStyle? contentTextStyle})
Creates a table row card theme.
const
TTableRowCardTheme.defaultTheme(ColorScheme colors)
factory

Properties

backgroundColor WidgetStateProperty<Color>
final
border WidgetStateProperty<Border>
final
borderRadius BorderRadius
final
contentTextStyle TextStyle?
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EdgeInsets? margin, EdgeInsets? padding, double? elevation, BorderRadius? borderRadius, WidgetStateProperty<Color>? backgroundColor, WidgetStateProperty<Border>? border, TextStyle? contentTextStyle}) TTableRowCardTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited