TTableDetails<T, K> class
Details and expansion configuration for the table.
Constructors
-
TTableDetails({TTableExpansionMode mode = TTableExpansionMode.bottom, TTableExpansionMode? createMode, String? itemTitle(T item)?, String? itemSubTitle(T item)?, String? itemDescription(T item)?, String? itemImageUrl(T item)?, List<
Widget> actions(T item)?, Future<bool> onWillExpand(K key)?, Future<bool> onWillCollapse(K key)?, bool focus = false, double? dimmedOpacity, TListExpandedBuilder<T, K> ? builder, TTableCreateBuilder<T, K> ? createBuilder, String? createTitle(T? item)?, Widget layoutBuilder(BuildContext context, TTableDetails<T, K> details, T? item, Widget child)?, bool showLayoutForBottom = false, double dialogWidth = 800.0, double? createDialogWidth}) -
const
Properties
-
actions
→ List<
Widget> Function(T item)? -
Actions to display in the page wrapper for a specific item. Only shown in view mode.
final
-
builder
→ TListExpandedBuilder<
T, K> ? -
Builder for expanded content of a row.
final
-
createBuilder
→ TTableCreateBuilder<
T, K> ? -
Builder for expanded content of a row when creating or editing.
final
- createDialogWidth → double?
-
The width of the dialog when creating or editing items in dialog mode. Defaults to dialogWidth or 800.
final
- createMode → TTableExpansionMode?
-
Defines how the expanded content is presented during creation/editing.
final
- createTitle → String? Function(T? item)?
-
Function to extract the title when creating/editing.
final
- dialogWidth → double
-
The width of the dialog when expansion mode is dialog. Defaults to 800.
final
- dimmedOpacity → double?
-
Opacity level to apply to headers and footer when table is dimmed.
final
- focus → bool
-
Whether to dim the rest of the table and scroll to the expanded item.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemDescription → String? Function(T item)?
-
Function to extract the description from an item (used in dialogs/pages).
final
- itemImageUrl → String? Function(T item)?
-
Function to extract the image URL from an item (used in dialogs/pages).
final
- itemSubTitle → String? Function(T item)?
-
Function to extract the sub-title from an item (used in dialogs/pages).
final
- itemTitle → String? Function(T item)?
-
Function to extract the title from an item (used in dialogs/pages).
final
-
layoutBuilder
→ Widget Function(BuildContext context, TTableDetails<
T, K> details, T? item, Widget child)? -
Optional layout builder for custom details wrapper.
final
- mode → TTableExpansionMode
-
Defines how the expanded content is presented.
final
-
onWillCollapse
→ Future<
bool> Function(K key)? -
Callback fired before the table's detail view / panel closes.
Return true to allow the close, or false to prevent it.
final
-
onWillExpand
→ Future<
bool> Function(K key)? -
Callback fired before a row expansion changes.
Return true to allow the expansion change, or false to prevent it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLayoutForBottom → bool
-
Whether to show the details layout/page wrapper when expansion mode is bottom.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited