TTabs<T> class
- Inheritance
- Available extensions
Constructors
-
TTabs({Key? key, required List<
TTab< tabs, TTabController<T> >T> ? controller, T? selectedValue, ValueChanged<T> ? onTabChanged, Color? borderColor, Color? selectedColor, Color? unselectedColor, Color? disabledColor, Color? indicatorColor, EdgeInsets? tabPadding, double tabSpacing = 2, double tabRunSpacing = 2, double? indicatorWidth = 1, bool inline = false, Axis axis = Axis.horizontal, bool scrollable = false, bool wrap = false, Widget tabBuilder(BuildContext, TTab<T> , bool, VoidCallback? )?, }) -
const
Properties
- axis → Axis
-
final
- borderColor → Color?
-
final
-
controller
→ TTabController<
T> ? -
final
- disabledColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicatorColor → Color?
-
final
- indicatorWidth → double?
-
final
- inline → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
final
-
final
-
onTabChanged
→ ValueChanged<
T> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollable → bool
-
final
- selectedColor → Color?
-
final
- selectedValue → T?
-
final
-
final
-
tabBuilder
→ Widget Function(BuildContext, TTab<
T> , bool, VoidCallback? )? -
final
- tabPadding → EdgeInsets?
-
final
- tabRunSpacing → double
-
final
-
tabs
→ List<
TTab< T> > -
final
- tabSpacing → double
-
final
- unselectedColor → Color?
-
final
- wrap → bool
-
final
Methods
-
box(
{double minW = 0.0, double minH = 0.0, double maxW = double.infinity, double maxH = double.infinity}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a ConstrainedBox to apply layout constraints. -
center(
{bool when = true}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Center widget. -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TTabs< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
estimateWidth(
BuildContext context) → double -
Available on TTabs, provided by the TTabsWidthX extension
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in an Expanded widget. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padding(
[double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0]) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with flexible edge control. -
paddingSymmetric(
{double h = 0.0, double v = 0.0}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Padding with symmetric horizontal and vertical spacing. -
size(
{double? w, double? h}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a SizedBox to apply fixed width and/or height. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
visible(
bool visible, {bool maintainState = false}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps this widget in a Visibility widget. -
when(
bool condition) → Widget -
Available on Widget, provided by the WidgetX extension
Returns this widget ifconditionis true, otherwise returns SizedBox.shrink(). Usage: Text('Hello').when(isVisible)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited