TTreeNode<T> class
A node in a TTreeView.
Constructors
Properties
- badge → String?
-
Optional badge string shown beside label.
final
-
children
→ List<
TTreeNode< T> > -
Child nodes nested under this node.
final
- data → T?
-
Optional underlying model/data payload.
final
- expandedIcon → dynamic
-
Optional icon when expanded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → dynamic
-
Optional icon when collapsed or if leaf.
final
- isDisabled → bool
-
Whether this node is disabled.
final
- isLeaf → bool?
-
Explicit flag whether this node is a terminal leaf.
final
- isLeafNode → bool
-
Whether this node has no children and is a leaf.
no setter
- isLoading → bool
-
Whether this node is currently loading children asynchronously.
final
- isSelectable → bool
-
Whether this node can be selected.
final
- key → String
-
Unique key identifying this node.
final
- label → String
-
Display text label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trailing → Widget?
-
Optional trailing widget (e.g. actions, counter).
final
Methods
-
copyWith(
{String? key, String? label, T? data, dynamic icon, dynamic expandedIcon, List< TTreeNode< ? children, bool? isLeaf, bool? isLoading, String? badge, Widget? trailing, bool? isSelectable, bool? isDisabled}) → TTreeNode<T> >T> - Creates a copy of this node with updated attributes.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited